@@ -20,6 +20,7 @@
 
 #include "resourcebase.h"
 #include "agentbase_p.h"
+#include "helper_p.h"
 
 #include "resourceadaptor.h"
 #include "collectiondeletejob.h"
@@ -53,12 +54,9 @@
 #include "akonadiagentbase_debug.h"
 #include <KLocalizedString>
 
-#include <QDir>
 #include <QHash>
-#include <QSettings>
 #include <QTimer>
 #include <QApplication>
-#include <QDBusConnection>
 
 using namespace Akonadi;
 
@@ -70,20 +68,20 @@ class Akonadi::ResourceBasePrivate : public AgentBasePrivate
 public:
     ResourceBasePrivate(ResourceBase *parent)
         : AgentBasePrivate(parent)
-        , scheduler(0)
-        , mItemSyncer(0)
-        , mItemSyncFetchScope(0)
+        , scheduler(nullptr)
+        , mItemSyncer(nullptr)
+        , mItemSyncFetchScope(nullptr)
         , mItemTransactionMode(ItemSync::SingleTransaction)
         , mItemMergeMode(ItemSync::RIDMerge)
-        , mCollectionSyncer(0)
-        , mTagSyncer(0)
-        , mRelationSyncer(0)
+        , mCollectionSyncer(nullptr)
+        , mTagSyncer(nullptr)
+        , mRelationSyncer(nullptr)
         , mHierarchicalRid(false)
         , mUnemittedProgress(0)
         , mAutomaticProgressReporting(true)
         , mDisableAutomaticItemDeliveryDone(false)
         , mItemSyncBatchSize(10)
-        , mCurrentCollectionFetchJob(0)
+        , mCurrentCollectionFetchJob(nullptr)
         , mScheduleAttributeSyncBeforeCollectionSync(false)
     {
         Internal::setClientType(Internal::Resource);
@@ -237,7 +235,7 @@ protected Q_SLOTS:
         AgentBasePrivate::itemAdded(item, collection);
     }
 
-    void itemChanged(const Akonadi::Item &item, const QSet< QByteArray > &partIdentifiers) Q_DECL_OVERRIDE {
+    void itemChanged(const Akonadi::Item &item, const QSet<QByteArray> &partIdentifiers) Q_DECL_OVERRIDE {
         if (item.remoteId().isEmpty())
         {
             changeProcessed();
@@ -246,8 +244,8 @@ protected Q_SLOTS:
         AgentBasePrivate::itemChanged(item, partIdentifiers);
     }
 
-    void itemsFlagsChanged(const Item::List &items, const QSet< QByteArray > &addedFlags,
-                           const QSet< QByteArray > &removedFlags) Q_DECL_OVERRIDE {
+    void itemsFlagsChanged(const Item::List &items, const QSet<QByteArray> &addedFlags,
+                           const QSet<QByteArray> &removedFlags) Q_DECL_OVERRIDE {
         if (addedFlags.isEmpty() && removedFlags.isEmpty())
         {
             changeProcessed();
@@ -255,7 +253,7 @@ protected Q_SLOTS:
         }
 
         Item::List validItems;
-        foreach (const Akonadi::Item &item, items)
+        for (const Akonadi::Item &item : items)
         {
             if (!item.remoteId().isEmpty()) {
                 validItems << item;
@@ -278,7 +276,7 @@ protected Q_SLOTS:
         }
 
         Item::List validItems;
-        foreach (const Akonadi::Item &item, items)
+        for (const Akonadi::Item &item : items)
         {
             if (!item.remoteId().isEmpty()) {
                 validItems << item;
@@ -311,7 +309,7 @@ protected Q_SLOTS:
         }
 
         Item::List validItems;
-        foreach (const Akonadi::Item &item, items)
+        for (const Akonadi::Item &item : items)
         {
             if (!item.remoteId().isEmpty()) {
                 validItems << item;
@@ -337,7 +335,7 @@ protected Q_SLOTS:
 
     void itemsRemoved(const Item::List &items) Q_DECL_OVERRIDE {
         Item::List validItems;
-        foreach (const Akonadi::Item &item, items)
+        for (const Akonadi::Item &item : items)
         {
             if (!item.remoteId().isEmpty()) {
                 validItems << item;
@@ -370,7 +368,7 @@ protected Q_SLOTS:
         AgentBasePrivate::collectionChanged(collection);
     }
 
-    void collectionChanged(const Akonadi::Collection &collection, const QSet< QByteArray > &partIdentifiers) Q_DECL_OVERRIDE {
+    void collectionChanged(const Akonadi::Collection &collection, const QSet<QByteArray> &partIdentifiers) Q_DECL_OVERRIDE {
         if (collection.remoteId().isEmpty())
         {
             changeProcessed();
@@ -606,8 +604,6 @@ QString ResourceBase::parseArguments(int argc, char **argv)
 
 int ResourceBase::init(ResourceBase *r)
 {
-#pragma message ("warning port to the new way of doing this")
-//   KLocalizedString::insertCatalog( QLatin1String( "libakonadi" ) );
     int rv = qApp->exec();
     delete r;
     return rv;
@@ -631,8 +627,8 @@ void ResourceBase::itemRetrieved(const Item &item)
     }
 
     Item i(item);
-    QSet<QByteArray> requestedParts = d->scheduler->currentTask().itemParts;
-    foreach (const QByteArray &part, requestedParts) {
+    const QSet<QByteArray> requestedParts = d->scheduler->currentTask().itemParts;
+    for (const QByteArray &part : requestedParts) {
         if (!item.loadedPayloadParts().contains(part)) {
             qCWarning(AKONADIAGENTBASE_LOG) << "Item does not provide part" << part;
         }
@@ -737,7 +733,7 @@ void ResourceBase::changesCommitted(const Item::List &items)
             this, SLOT(changeCommittedResult(KJob*)));
 
     // Modify the items one-by-one, because STORE does not support mass RID change
-    Q_FOREACH (const Item &item, items) {
+    for (const Item &item : items) {
         ItemModifyJob *job = new ItemModifyJob(item, transaction);
         job->d_func()->setClean();
         job->disableRevisionCheck(); // TODO: remove, but where/how do we handle the error?
@@ -877,7 +873,7 @@ void ResourceBase::setKeepLocalCollectionChanges(const QSet<QByteArray> &parts)
 void ResourceBasePrivate::slotCollectionSyncDone(KJob *job)
 {
     Q_Q(ResourceBase);
-    mCollectionSyncer = 0;
+    mCollectionSyncer = nullptr;
     if (job->error()) {
         if (job->error() != Job::UserCanceled) {
             emit q->error(job->errorString());
@@ -903,8 +899,8 @@ void ResourceBasePrivate::slotLocalListDone(KJob *job)
     if (job->error()) {
         emit q->error(job->errorString());
     } else {
-        Collection::List cols = static_cast<CollectionFetchJob *>(job)->collections();
-        foreach (const Collection &col, cols) {
+        const Collection::List cols = static_cast<CollectionFetchJob *>(job)->collections();
+        for (const Collection &col : cols) {
             scheduler->scheduleSync(col);
         }
         scheduler->scheduleFullSyncCompletion();
@@ -940,7 +936,7 @@ void ResourceBasePrivate::slotSynchronizeCollection(const Collection &col)
 void ResourceBasePrivate::slotItemRetrievalCollectionFetchDone(KJob *job)
 {
     Q_Q(ResourceBase);
-    mCurrentCollectionFetchJob = 0;
+    mCurrentCollectionFetchJob = nullptr;
     if (job->error()) {
         qCWarning(AKONADIAGENTBASE_LOG) << "Failed to retrieve collection for sync: " << job->errorString();
         q->cancelTask(i18n("Failed to retrieve collection for sync."));
@@ -986,7 +982,7 @@ void ResourceBasePrivate::slotSynchronizeCollectionAttributes(const Collection &
 
 void ResourceBasePrivate::slotAttributeRetrievalCollectionFetchDone(KJob *job)
 {
-    mCurrentCollectionFetchJob = 0;
+    mCurrentCollectionFetchJob = nullptr;
     Q_Q(ResourceBase);
     if (job->error()) {
         qCWarning(AKONADIAGENTBASE_LOG) << "Failed to retrieve collection for attribute sync: " << job->errorString();
@@ -1015,7 +1011,7 @@ void ResourceBasePrivate::slotPrepareItemRetrieval(const Item &item)
     auto fetch = new ItemFetchJob(item, this);
     // we always need at least parent so we can use ItemCreateJob to merge
     fetch->fetchScope().setAncestorRetrieval(qMax(ItemFetchScope::Parent,
-                                                  q->changeRecorder()->itemFetchScope().ancestorRetrieval()));
+            q->changeRecorder()->itemFetchScope().ancestorRetrieval()));
     fetch->fetchScope().setCacheOnly(true);
     fetch->fetchScope().setFetchRemoteIdentification(true);
 
@@ -1055,7 +1051,7 @@ void ResourceBasePrivate::slotPrepareItemsRetrieval(const QVector<Item> &items)
     ItemFetchJob *fetch = new ItemFetchJob(items, this);
     // we always need at least parent so we can use ItemCreateJob to merge
     fetch->fetchScope().setAncestorRetrieval(qMax(ItemFetchScope::Parent,
-                                                  q->changeRecorder()->itemFetchScope().ancestorRetrieval()));
+            q->changeRecorder()->itemFetchScope().ancestorRetrieval()));
     fetch->fetchScope().setCacheOnly(true);
     fetch->fetchScope().setFetchRemoteIdentification(true);
     // It's possible that one or more items were removed before this task was
@@ -1102,7 +1098,7 @@ void ResourceBasePrivate::slotRecursiveMoveReplay(RecursiveMover *mover)
 void ResourceBasePrivate::slotRecursiveMoveReplayResult(KJob *job)
 {
     Q_Q(ResourceBase);
-    m_recursiveMover = 0;
+    m_recursiveMover = nullptr;
 
     if (job->error()) {
         q->deferTask();
@@ -1186,7 +1182,7 @@ void ResourceBase::cancelTask()
     Q_D(ResourceBase);
     if (d->mCurrentCollectionFetchJob) {
         d->mCurrentCollectionFetchJob->kill();
-        d->mCurrentCollectionFetchJob = 0;
+        d->mCurrentCollectionFetchJob = nullptr;
     }
     switch (d->scheduler->currentTask().type) {
     case ResourceScheduler::FetchItem:
@@ -1251,7 +1247,7 @@ void ResourceBasePrivate::slotCollectionListDone(KJob *job)
 {
     if (!job->error()) {
         const Collection::List list = static_cast<CollectionFetchJob *>(job)->collections();
-        Q_FOREACH (const Collection &collection, list) {
+        for (const Collection &collection : list) {
             //We also get collections that should not be synced but are part of the tree.
             if (collection.shouldList(Collection::ListSync) || collection.referenced()) {
                 if (mScheduleAttributeSyncBeforeCollectionSync) {
@@ -1282,9 +1278,9 @@ void ResourceBase::synchronizeCollectionAttributes(qint64 collectionId)
 void ResourceBasePrivate::slotCollectionListForAttributesDone(KJob *job)
 {
     if (!job->error()) {
-        Collection::List list = static_cast<CollectionFetchJob *>(job)->collections();
+        const Collection::List list = static_cast<CollectionFetchJob *>(job)->collections();
         if (!list.isEmpty()) {
-            Collection col = list.first();
+            const Collection col = list.first();
             scheduler->scheduleAttributesSync(col);
         }
     }
@@ -1326,7 +1322,7 @@ void ResourceBase::itemsRetrieved(const Item::List &items)
         auto trx = new TransactionSequence(this);
         connect(trx, SIGNAL(result(KJob*)),
                 this, SLOT(slotItemSyncDone(KJob*)));
-        Q_FOREACH (const Item &item, items) {
+        for (const Item &item : items) {
             Q_ASSERT(item.parentCollection().isValid());
             if (!item.remoteId().isEmpty()) {
                 auto job = new ItemCreateJob(item, item.parentCollection(), trx);
@@ -1357,7 +1353,7 @@ void ResourceBase::itemsRetrievedIncremental(const Item::List &changedItems,
 
 void ResourceBasePrivate::slotItemSyncDone(KJob *job)
 {
-    mItemSyncer = 0;
+    mItemSyncer = nullptr;
     Q_Q(ResourceBase);
     if (job->error() && job->error() != Job::UserCanceled) {
         emit q->error(job->errorString());
@@ -1373,7 +1369,7 @@ void ResourceBasePrivate::slotDelayedEmitProgress()
     if (mAutomaticProgressReporting) {
         emit q->percent(mUnemittedProgress);
 
-        Q_FOREACH (const QVariantMap &statusMap, mUnemittedAdvancedStatus) {
+        for (const QVariantMap &statusMap : qAsConst(mUnemittedAdvancedStatus)) {
             emit q->advancedStatus(statusMap);
         }
     }
@@ -1454,7 +1450,7 @@ bool ResourceBase::retrieveItem(const Akonadi::Item &item, const QSet<QByteArray
     return false;
 }
 
-bool ResourceBase::retrieveItems(const Akonadi::Item::List& items, const QSet<QByteArray>& parts)
+bool ResourceBase::retrieveItems(const Akonadi::Item::List &items, const QSet<QByteArray> &parts)
 {
     Q_D(ResourceBase);
 
@@ -1470,7 +1466,6 @@ bool ResourceBase::retrieveItems(const Akonadi::Item::List& items, const QSet<QB
     return true;
 }
 
-
 void Akonadi::ResourceBase::abortActivity()
 {
 }
@@ -1546,7 +1541,7 @@ void ResourceBase::tagsRetrieved(const Tag::List &tags, const QHash<QString, Ite
 void ResourceBasePrivate::slotTagSyncDone(KJob *job)
 {
     Q_Q(ResourceBase);
-    mTagSyncer = 0;
+    mTagSyncer = nullptr;
     if (job->error()) {
         if (job->error() != Job::UserCanceled) {
             qCWarning(AKONADIAGENTBASE_LOG) << "TagSync failed: " << job->errorString();
@@ -1576,7 +1571,7 @@ void ResourceBase::relationsRetrieved(const Relation::List &relations)
 void ResourceBasePrivate::slotRelationSyncDone(KJob *job)
 {
     Q_Q(ResourceBase);
-    mRelationSyncer = 0;
+    mRelationSyncer = nullptr;
     if (job->error()) {
         if (job->error() != Job::UserCanceled) {
             qCWarning(AKONADIAGENTBASE_LOG) << "RelationSync failed: " << job->errorString();
