@@ -21,8 +21,9 @@
 
 #include "KDBusConnectionPool"
 #include "recursivemover_p.h"
-
+#include "helper_p.h"
 #include "akonadiagentbase_debug.h"
+#include "private/instance_p.h"
 #include <KLocalizedString>
 
 #include <QTimer>
@@ -32,7 +33,7 @@
 using namespace Akonadi;
 
 qint64 ResourceScheduler::Task::latestSerial = 0;
-static QDBusAbstractInterface *s_resourcetracker = 0;
+static QDBusAbstractInterface *s_resourcetracker = nullptr;
 
 //@cond PRIVATE
 
@@ -125,7 +126,7 @@ void ResourceScheduler::scheduleAttributesSync(const Collection &collection)
 }
 
 void ResourceScheduler::scheduleItemFetch(const Akonadi::Item &item, const QSet<QByteArray> &parts,
-                                          const QList<QDBusMessage> &msgs, qint64 parentId)
+        const QList<QDBusMessage> &msgs, qint64 parentId)
 
 {
     Task t;
@@ -142,7 +143,6 @@ void ResourceScheduler::scheduleItemFetch(const Akonadi::Item &item, const QSet<
     scheduleNext();
 }
 
-
 void ResourceScheduler::scheduleItemsFetch(const Item::List &items, const QSet<QByteArray> &parts, const QDBusMessage &msg)
 {
     Task t;
@@ -296,9 +296,7 @@ void ResourceScheduler::taskDone()
     }
 
     if (s_resourcetracker) {
-        QList<QVariant> argumentList;
-        argumentList << QString::number(mCurrentTask.serial)
-                     << QString();
+        const QList<QVariant> argumentList = { QString::number(mCurrentTask.serial), QString() };
         s_resourcetracker->asyncCallWithArgumentList(QStringLiteral("jobEnded"), argumentList);
     }
 
@@ -344,7 +342,6 @@ void ResourceScheduler::itemFetchDone(const QString &msg)
     taskDone();
 }
 
-
 void ResourceScheduler::deferTask()
 {
     if (mCurrentTask.type == Invalid) {
@@ -352,9 +349,7 @@ void ResourceScheduler::deferTask()
     }
 
     if (s_resourcetracker) {
-        QList<QVariant> argumentList;
-        argumentList << QString::number(mCurrentTask.serial)
-                     << QString();
+        const QList<QVariant> argumentList = {QString::number(mCurrentTask.serial), QString()};
         s_resourcetracker->asyncCallWithArgumentList(QStringLiteral("jobEnded"), argumentList);
     }
 
@@ -403,8 +398,7 @@ void ResourceScheduler::executeNext()
     }
 
     if (s_resourcetracker) {
-        QList<QVariant> argumentList;
-        argumentList << QString::number(mCurrentTask.serial);
+        const QList<QVariant> argumentList = { QString::number(mCurrentTask.serial) };
         s_resourcetracker->asyncCallWithArgumentList(QStringLiteral("jobStarted"), argumentList);
     }
 
@@ -520,9 +514,7 @@ void ResourceScheduler::setOnline(bool state)
                 lastTask = (*it);
                 it = itemFetchQueue.erase(it);
                 if (s_resourcetracker) {
-                    QList<QVariant> argumentList;
-                    argumentList << QString::number(mCurrentTask.serial)
-                                 << i18nc("@info", "Job canceled.");
+                    const QList<QVariant> argumentList = { QString::number(mCurrentTask.serial), i18nc("@info", "Job canceled.")};
                     s_resourcetracker->asyncCallWithArgumentList(QStringLiteral("jobEnded"), argumentList);
                 }
             } else {
@@ -535,21 +527,24 @@ void ResourceScheduler::setOnline(bool state)
 void ResourceScheduler::signalTaskToTracker(const Task &task, const QByteArray &taskType, const QString &debugString)
 {
     // if there's a job tracer running, tell it about the new job
-    if (!s_resourcetracker && KDBusConnectionPool::threadConnection().interface()->isServiceRegistered(QStringLiteral("org.kde.akonadiconsole"))) {
-        s_resourcetracker = new QDBusInterface(QStringLiteral("org.kde.akonadiconsole"),
-                                               QStringLiteral("/resourcesJobtracker"),
-                                               QStringLiteral("org.freedesktop.Akonadi.JobTracker"),
-                                               KDBusConnectionPool::threadConnection(), 0);
+    if (!s_resourcetracker) {
+        const QString suffix = Akonadi::Instance::identifier().isEmpty() ? QString() : QLatin1Char('-') + Akonadi::Instance::identifier();
+        if (KDBusConnectionPool::threadConnection().interface()->isServiceRegistered(QStringLiteral("org.kde.akonadiconsole") + suffix)) {
+            s_resourcetracker = new QDBusInterface(QStringLiteral("org.kde.akonadiconsole") + suffix,
+                                                   QStringLiteral("/resourcesJobtracker"),
+                                                   QStringLiteral("org.freedesktop.Akonadi.JobTracker"),
+                                                   KDBusConnectionPool::threadConnection(), nullptr);
+        }
     }
 
     if (s_resourcetracker) {
-        QList<QVariant> argumentList;
-        argumentList << static_cast<AgentBase *>(parent())->identifier()   // "session" (in our case resource)
-                     << QString::number(task.serial)                       // "job"
-                     << QString()                                          // "parent job"
-                     << QString::fromLatin1(taskType)                      // "job type"
-                     << debugString                                        // "job debugging string"
-                     ;
+        const QList<QVariant> argumentList = QList<QVariant>()
+                << static_cast<AgentBase *>(parent())->identifier()   // "session" (in our case resource)
+                << QString::number(task.serial)                       // "job"
+                << QString()                                          // "parent job"
+                << QString::fromLatin1(taskType)                      // "job type"
+                << debugString                                        // "job debugging string"
+                   ;
         s_resourcetracker->asyncCallWithArgumentList(QStringLiteral("jobCreated"), argumentList);
     }
 }
@@ -572,7 +567,7 @@ void ResourceScheduler::collectionRemoved(const Akonadi::Collection &collection)
 
 void ResourceScheduler::Task::sendDBusReplies(const QString &errorMsg)
 {
-    Q_FOREACH (const QDBusMessage &msg, dbusMsgs) {
+    for (const QDBusMessage &msg : qAsConst(dbusMsgs)) {
         QDBusMessage reply(msg.createReply());
         const QString methodName = msg.member();
         if (methodName == QLatin1String("requestItemDelivery")) {
@@ -624,7 +619,7 @@ QString ResourceScheduler::dumpToString() const
             str << " queue " << i << " is empty" << endl;
         } else {
             str << " queue " << i << " " << queue.size() << " tasks:" << endl;
-            QList<Task>::const_iterator queueEnd(queue.constEnd());
+            const QList<Task>::const_iterator queueEnd(queue.constEnd());
             for (QList<Task>::const_iterator it = queue.constBegin(); it != queueEnd; ++it) {
                 str << "  " << (*it) << endl;
             }
@@ -688,7 +683,7 @@ QTextStream &Akonadi::operator<<(QTextStream &d, const ResourceScheduler::Task &
         if (!task.items.isEmpty()) {
             QStringList ids;
             ids.reserve(task.items.size());
-            for (const auto &item : task.items) {
+            for (const auto &item : qAsConst(task.items)) {
                 ids.push_back(QString::number(item.id()));
             }
             d << "items " << ids.join(QStringLiteral(", ")) << " ";
