@@ -22,7 +22,8 @@
 
 #include <QThread>
 
-namespace Akonadi {
+namespace Akonadi
+{
 
 /**
  * @short A class that encapsulates an agent instance inside a thread.
@@ -39,7 +40,7 @@ public:
      * @param factory The factory object that creates the agent instance.
      * @param parent The parent object.
      */
-    AgentThread(const QString &identifier, QObject *factory, QObject *parent = Q_NULLPTR);
+    AgentThread(const QString &identifier, QObject *factory, QObject *parent = nullptr);
 
     /**
      * Configures the agent.
