@@ -30,7 +30,6 @@
 #include <QGuiApplication>
 #include <QSessionManager>
 #include <QDBusConnection>
-#include <QDBusError>
 
 #include <KCrash/KCrash>
 #include <KAboutData>
@@ -40,7 +39,7 @@
 # include <unistd.h>
 #endif
 
-static AgentManager *sAgentManager = 0;
+static AgentManager *sAgentManager = nullptr;
 
 void crashHandler(int)
 {
@@ -89,11 +88,10 @@ int main(int argc, char **argv)
     sAgentManager = new AgentManager(app.commandLineArguments().isSet(QStringLiteral("verbose")));
     KCrash::setEmergencySaveFunction(crashHandler);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
     QGuiApplication::setFallbackSessionManagementEnabled(false);
-#endif
+
     // akonadi_control is started on-demand, no need to auto restart by session.
-    auto disableSessionManagement = [](QSessionManager &sm) {
+    auto disableSessionManagement = [](QSessionManager & sm) {
         sm.setRestartHint(QSessionManager::RestartNever);
     };
     QObject::connect(qApp, &QGuiApplication::commitDataRequest, disableSessionManagement);
@@ -102,7 +100,7 @@ int main(int argc, char **argv)
     int retval = app.exec();
 
     delete sAgentManager;
-    sAgentManager = 0;
+    sAgentManager = nullptr;
 
     return retval;
 }
