@@ -31,7 +31,6 @@
 #include <KConfig>
 #include <KConfigGroup>
 
-#include <QDBusConnection>
 #include <QDBusInterface>
 #include <QDBusReply>
 #include <QDir>
@@ -47,8 +46,8 @@ using namespace Akonadi;
 Firstrun::Firstrun(QObject *parent)
     : QObject(parent)
     , mConfig(new KConfig(ServerManager::addNamespace(QStringLiteral("akonadi-firstrunrc"))))
-    , mCurrentDefault(0)
-    , mProcess(0)
+    , mCurrentDefault(nullptr)
+    , mProcess(nullptr)
 {
     //The code in firstrun is not safe in multi-instance mode
     Q_ASSERT(!ServerManager::hasInstanceIdentifier());
@@ -80,9 +79,9 @@ void Firstrun::findPendingDefaults()
 {
     const KConfigGroup cfg(mConfig, "ProcessedDefaults");
     const QStringList paths = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("akonadi/firstrun"), QStandardPaths::LocateDirectory);
-    foreach (const QString &dirName, paths) {
+    for (const QString &dirName : paths) {
         const QStringList files = QDir(dirName).entryList(QDir::Files | QDir::Readable);
-        foreach (const QString &fileName, files) {
+        for (const QString &fileName : files) {
             const QString fullName = dirName + QLatin1Char('/') + fileName;
             KConfig c(fullName);
             const QString id = KConfigGroup(&c, "Agent").readEntry("Id", QString());
@@ -102,7 +101,7 @@ void Firstrun::findPendingDefaults()
 void Firstrun::setupNext()
 {
     delete mCurrentDefault;
-    mCurrentDefault = 0;
+    mCurrentDefault = nullptr;
 
     if (mPendingDefaults.isEmpty()) {
         deleteLater();
@@ -119,7 +118,8 @@ void Firstrun::setupNext()
         return;
     }
     if (type.capabilities().contains(QStringLiteral("Unique"))) {
-        Q_FOREACH (const AgentInstance &agent, AgentManager::self()->instances()) {
+        const Akonadi::AgentInstance::List lstAgents = AgentManager::self()->instances();
+        for (const AgentInstance &agent : lstAgents) {
             if (agent.type() == type) {
                 // remember we set this one up already
                 KConfigGroup cfg(mConfig, "ProcessedDefaults");
@@ -153,7 +153,6 @@ void Firstrun::instanceCreated(KJob *job)
         instance.setName(agentName);
     }
 
-
     QDBusInterface *iface = new QDBusInterface(QStringLiteral("org.freedesktop.Akonadi.Agent.%1").arg(instance.identifier()),
             QStringLiteral("/Settings"), QString(),
             KDBusConnectionPool::threadConnection(), this);
@@ -166,7 +165,8 @@ void Firstrun::instanceCreated(KJob *job)
     // agent specific settings, using the D-Bus <-> KConfigXT bridge
     const KConfigGroup settings = KConfigGroup(mCurrentDefault, "Settings");
 
-    foreach (const QString &setting, settings.keyList()) {
+    const QStringList lstSettings = settings.keyList();
+    for (const QString &setting : lstSettings) {
         qCDebug(AKONADICORE_LOG) << "Setting up " << setting << " for agent " << instance.identifier();
         const QString methodName = QStringLiteral("set%1").arg(setting);
         const QVariant::Type argType = argumentType(iface->metaObject(), methodName);
