@@ -29,13 +29,12 @@
 #include "protocolhelper_p.h"
 #include "gidextractor_p.h"
 #include "private/protocol_p.h"
+#include "helper_p.h"
 
 #include <QDateTime>
-#include <QFile>
 
 #include <KLocalizedString>
 
-
 using namespace Akonadi;
 
 class Akonadi::ItemCreateJobPrivate : public JobPrivate
@@ -50,16 +49,27 @@ public:
 
     Protocol::PartMetaData preparePart(const QByteArray &part);
 
+    QString jobDebuggingString() const Q_DECL_OVERRIDE;
     Collection mCollection;
     Item mItem;
     QSet<QByteArray> mParts;
-    Item::Id mUid;
     QDateTime mDatetime;
     QByteArray mPendingData;
     ItemCreateJob::MergeOptions mMergeOptions;
     bool mItemReceived;
+
 };
 
+QString Akonadi::ItemCreateJobPrivate::jobDebuggingString() const
+{
+    const QString collectionName = mCollection.name();
+    QString str = QStringLiteral("Create Item %1 from col %2").arg(mItem.id()).arg(mCollection.id());
+    if (!collectionName.isEmpty()) {
+        str += QStringLiteral(" (%1)").arg(collectionName);
+    }
+    return str;
+}
+
 Protocol::PartMetaData ItemCreateJobPrivate::preparePart(const QByteArray &partName)
 {
     ProtocolHelper::PartNamespace ns; //dummy
@@ -149,7 +159,7 @@ void ItemCreateJob::doStart()
     cmd.setAttributes(ProtocolHelper::attributesToProtocol(d->mItem));
     QSet<QByteArray> parts;
     parts.reserve(d->mParts.size());
-    Q_FOREACH (const QByteArray &part, d->mParts) {
+    for (const QByteArray &part : qAsConst(d->mParts)) {
         parts.insert(ProtocolHelper::encodePartIdentifier(ProtocolHelper::PartPayload, part));
     }
     cmd.setParts(parts);
