@@ -39,7 +39,7 @@ class JobPrivate
 public:
     explicit JobPrivate(Job *parent)
         : q_ptr(parent)
-        , mParentJob(Q_NULLPTR)
+        , mParentJob(nullptr)
         , mCurrentSubJob(0)
         , mTag(-1)
         , mSession(0)
