@@ -27,6 +27,7 @@
 #include "agentmanager.h"
 #include "collectioncreatejob.h"
 #include "entitydisplayattribute.h"
+#include "helper_p.h"
 
 #include "akonadicore_debug.h"
 
@@ -85,24 +86,24 @@ bool SpecialCollectionsRequestJobPrivate::isEverythingReady()
 {
     // check if all requested folders are known already
     if (mRequestingDefaultFolders) {
-        QHashIterator<QByteArray, bool> it(mDefaultFolders);
-        while (it.hasNext()) {
-            it.next();
+        QHash<QByteArray, bool>::const_iterator it = mDefaultFolders.constBegin();
+        const QHash<QByteArray, bool>::const_iterator end = mDefaultFolders.constEnd();
+        while (it != end) {
             if (it.value() && !mSpecialCollections->hasDefaultCollection(it.key())) {
                 return false;
             }
+            it++;
         }
     }
 
-    const QStringList resourceIds = mFoldersForResource.keys();
     QHashIterator<QString, QHash<QByteArray, bool> > resourceIt(mFoldersForResource);
     while (resourceIt.hasNext()) {
         resourceIt.next();
 
         const QHash<QByteArray, bool> &requested = resourceIt.value();
-        QHashIterator<QByteArray, bool> it(requested);
-        while (it.hasNext()) {
-            it.next();
+        QHash<QByteArray, bool>::const_iterator it = requested.cbegin();
+        const QHash<QByteArray, bool>::const_iterator itEnd = requested.cend();
+        for (;it != itEnd; ++it) {
             if (it.value() && !mSpecialCollections->hasCollection(it.key(), AgentManager::self()->instance(resourceIt.key()))) {
                 return false;
             }
@@ -153,13 +154,13 @@ void SpecialCollectionsRequestJobPrivate::nextResource()
         mSpecialCollections->d->beginBatchRegister();
 
         // Forget everything we knew before about these resources.
-        foreach (const QString &resourceId, mToForget) {
+        for (const QString &resourceId : qAsConst(mToForget)) {
             mSpecialCollections->d->forgetFoldersForResource(resourceId);
         }
 
         // Register all the collections that we fetched / created.
         typedef QPair<Collection, QByteArray> RegisterPair;
-        foreach (const RegisterPair &pair, mToRegister) {
+        for (const RegisterPair &pair : qAsConst(mToRegister)) {
             const bool ok = mSpecialCollections->registerCollection(pair.second, pair.first);
             Q_ASSERT(ok);
             Q_UNUSED(ok);
@@ -216,7 +217,8 @@ void SpecialCollectionsRequestJobPrivate::createRequestedFolders(ResourceScanJob
         QHash<QByteArray, bool> &requestedFolders)
 {
     // Remove from the request list the folders which already exist.
-    foreach (const Collection &collection, scanJob->specialCollections()) {
+    const Akonadi::Collection::List lstSpecialCols = scanJob->specialCollections();
+    for (const Collection &collection : lstSpecialCols) {
         Q_ASSERT(collection.hasAttribute<SpecialCollectionAttribute>());
         const SpecialCollectionAttribute *attr = collection.attribute<SpecialCollectionAttribute>();
         const QByteArray type = attr->collectionType();
