@@ -24,7 +24,6 @@
 
 #include <QHash>
 #include <QMimeData>
-#include <QTimer>
 #include <QAbstractProxyModel>
 #include <QMessageBox>
 
@@ -40,6 +39,7 @@
 #include "itemmodifyjob.h"
 #include "session.h"
 #include "collectionfetchscope.h"
+#include "helper_p.h"
 
 #include "collectionutils.h"
 
@@ -68,7 +68,7 @@ EntityTreeModel::~EntityTreeModel()
 {
     Q_D(EntityTreeModel);
 
-    foreach (const QList<Node *> &list, d->m_childEntities) {
+    for (const QList<Node *> &list : qAsConst(d->m_childEntities)) {
         QList<Node *>::const_iterator it = list.constBegin();
         const QList<Node *>::const_iterator end = list.constEnd();
         for (; it != end; ++it) {
@@ -76,7 +76,7 @@ EntityTreeModel::~EntityTreeModel()
         }
     }
 
-    d->m_rootNode = 0;
+    d->m_rootNode = nullptr;
 
     delete d_ptr;
 }
@@ -100,10 +100,11 @@ void EntityTreeModel::setCollectionsMonitored(const Collection::List &collection
 {
     Q_D(EntityTreeModel);
     d->beginResetModel();
-    foreach (const Akonadi::Collection &col, d->m_monitor->collectionsMonitored()) {
+    const Akonadi::Collection::List lstCols = d->m_monitor->collectionsMonitored();
+    for (const Akonadi::Collection &col : lstCols) {
         d->m_monitor->setCollectionMonitored(col, false);
     }
-    foreach (const Akonadi::Collection &col, collections) {
+    for (const Akonadi::Collection &col : collections) {
         d->m_monitor->setCollectionMonitored(col, true);
     }
     d->endResetModel();
@@ -386,7 +387,7 @@ Qt::ItemFlags EntityTreeModel::flags(const QModelIndex &index) const
     Q_D(const EntityTreeModel);
     // Pass modeltest.
     if (!index.isValid()) {
-        return 0;
+        return nullptr;
     }
 
     Qt::ItemFlags flags = QAbstractItemModel::flags(index);
@@ -530,7 +531,7 @@ bool EntityTreeModel::dropMimeData(const QMimeData *data, Qt::DropAction action,
             mimeChecker.setWantedMimeTypes(destCollection.contentMimeTypes());
 
             const QList<QUrl> urls = data->urls();
-            foreach (const QUrl &url, urls) {
+            for (const QUrl &url : urls) {
                 const Collection collection = d->m_collections.value(Collection::fromUrl(url).id());
                 if (collection.isValid()) {
                     if (collection.parentCollection().id() == destCollection.id() &&
@@ -550,7 +551,7 @@ bool EntityTreeModel::dropMimeData(const QMimeData *data, Qt::DropAction action,
                         const QStringList collectionNames = d->childCollectionNames(destCollection);
 
                         if (collectionNames.contains(collectionName)) {
-                            QMessageBox::critical(0, i18n("Error"),
+                            QMessageBox::critical(nullptr, i18n("Error"),
                                                   i18n("The target collection '%1' contains already\na collection with name '%2'.",
                                                        destCollection.name(), collection.name()));
                             return false;
@@ -753,7 +754,7 @@ QMimeData *EntityTreeModel::mimeData(const QModelIndexList &indexes) const
 
     QMimeData *data = new QMimeData();
     QList<QUrl> urls;
-    foreach (const QModelIndex &index, indexes) {
+    for (const QModelIndex &index : indexes) {
         if (index.column() != 0) {
             continue;
         }
@@ -1190,9 +1191,9 @@ QModelIndexList EntityTreeModel::modelIndexesForItem(const QAbstractItemModel *m
         return QModelIndexList();
     }
 
-    QModelIndexList list = pair.second->d_ptr->indexesForItem(item);
+    const QModelIndexList list = pair.second->d_ptr->indexesForItem(item);
     QModelIndexList proxyList;
-    foreach (const QModelIndex &idx, list) {
+    for (const QModelIndex &idx : list) {
         const QModelIndex pIdx = proxiedIndex(idx, pair.first);
         if (pIdx.isValid()) {
             proxyList << pIdx;
