@@ -21,7 +21,6 @@
 #include "entitytreemodel.h"
 
 #include "agentmanagerinterface.h"
-#include "KDBusConnectionPool"
 #include "monitor_p.h" // For friend ref/deref
 #include "servermanager.h"
 #include "vectorhelper.h"
@@ -74,13 +73,14 @@ static CollectionFetchJob::Type getFetchType(EntityTreeModel::CollectionFetchStr
 EntityTreeModelPrivate::EntityTreeModelPrivate(EntityTreeModel *parent)
     : q_ptr(parent)
     , m_monitor(nullptr)
-    , m_rootNode(0)
+    , m_rootNode(nullptr)
     , m_collectionFetchStrategy(EntityTreeModel::FetchCollectionsRecursive)
     , m_itemPopulation(EntityTreeModel::ImmediatePopulation)
     , m_listFilter(CollectionFetchScope::NoFilter)
     , m_includeStatistics(false)
     , m_showRootCollection(false)
     , m_collectionTreeFetched(false)
+    , m_session(nullptr)
     , m_showSystemEntities(false)
 {
     // using collection as a parameter of a queued call in runItemFetchJob()
@@ -109,7 +109,7 @@ void EntityTreeModelPrivate::init(Monitor *monitor)
 
     m_rootCollectionDisplayName = QStringLiteral("[*]");
 
-    if (Akonadi::ChangeRecorder *cr = qobject_cast<Akonadi::ChangeRecorder*>(m_monitor)) {
+    if (Akonadi::ChangeRecorder *cr = qobject_cast<Akonadi::ChangeRecorder *>(m_monitor)) {
         cr->setChangeRecordingEnabled(false);
     }
 
@@ -523,7 +523,7 @@ void EntityTreeModelPrivate::itemsFetched(const Collection::Id collectionId, con
             bool isNewItem = true;
             if (m_items.contains(item.id())) {
                 const Akonadi::Collection::List parents = getParentCollections(item);
-                foreach (const Akonadi::Collection &parent, parents) {
+                for (const Akonadi::Collection &parent : parents) {
                     if (parent.id() == collectionId) {
                         qCWarning(AKONADICORE_LOG) << "Fetched an item which is already in the model";
                         // Update it in case the revision changed;
@@ -540,7 +540,7 @@ void EntityTreeModelPrivate::itemsFetched(const Collection::Id collectionId, con
         }
     }
 
-    if (itemsToInsert.size() > 0) {
+    if (!itemsToInsert.isEmpty()) {
         const Collection::Id colId = m_collectionFetchStrategy == EntityTreeModel::InvisibleCollectionFetch ? m_rootCollection.id()
                                      : m_collectionFetchStrategy == EntityTreeModel::FetchNoCollections ? m_rootCollection.id()
                                      : collectionId;
@@ -691,7 +691,7 @@ void EntityTreeModelPrivate::retrieveAncestors(const Akonadi::Collection &collec
 
 void EntityTreeModelPrivate::ancestorsFetched(const Akonadi::Collection::List &collectionList)
 {
-    foreach (const Collection &collection, collectionList) {
+    for (const Collection &collection : collectionList) {
         m_collections[collection.id()] = collection;
 
         const QModelIndex index = indexForCollection(collection);
@@ -1163,11 +1163,11 @@ void EntityTreeModelPrivate::monitoredItemChanged(const Akonadi::Item &item, con
     }
 
     const QModelIndexList indexes = indexesForItem(item);
-    foreach (const QModelIndex &index, indexes) {
-        if (!index.isValid()) {
-            qCWarning(AKONADICORE_LOG) << "item has invalid index:" << item.id() << item.remoteId();
-        } else {
+    for (const QModelIndex &index : indexes) {
+        if (index.isValid()) {
             dataChanged(index, index);
+        } else {
+            qCWarning(AKONADICORE_LOG) << "item has invalid index:" << item.id() << item.remoteId();
         }
     }
 }
@@ -1387,7 +1387,7 @@ void EntityTreeModelPrivate::pasteJobDone(KJob *job)
 
         errorMsg += QLatin1Char(' ') + job->errorString();
 
-        QMessageBox::critical(0, i18n("Error"), errorMsg);
+        QMessageBox::critical(nullptr, i18n("Error"), errorMsg);
     }
 }
 
@@ -1411,7 +1411,7 @@ void EntityTreeModelPrivate::updateJobDone(KJob *job)
         m_items[item.id()].apply(item);
         const QModelIndexList list = indexesForItem(item);
 
-        foreach (const QModelIndex &index, list) {
+        for (const QModelIndex &index : list) {
             dataChanged(index, index);
         }
     }
@@ -1435,7 +1435,7 @@ void EntityTreeModelPrivate::startFirstListJob()
 {
     Q_Q(EntityTreeModel);
 
-    if (m_collections.size() > 0) {
+    if (!m_collections.isEmpty()) {
         return;
     }
 
@@ -1515,7 +1515,7 @@ void EntityTreeModelPrivate::fetchTopLevelCollections() const
 void EntityTreeModelPrivate::topLevelCollectionsFetched(const Akonadi::Collection::List &list)
 {
     Q_Q(EntityTreeModel);
-    foreach (const Collection &collection, list) {
+    for (const Collection &collection : list) {
         // These collections have been explicitly shown in the Monitor,
         // but hidden trumps that for now. This may change in the future if we figure out a use for it.
         if (isHidden(collection)) {
@@ -1779,7 +1779,7 @@ QModelIndexList EntityTreeModelPrivate::indexesForItem(const Item &item) const
     const Collection::List collections = getParentCollections(item);
 
     indexes.reserve(collections.size());
-    foreach (const Collection &collection, collections) {
+    for (const Collection &collection : collections) {
         const int row = indexOf<Node::Item>(m_childEntities.value(collection.id()), item.id());
         Q_ASSERT(row >= 0);
         Q_ASSERT(m_childEntities.contains(collection.id()));
@@ -1817,7 +1817,7 @@ void EntityTreeModelPrivate::endResetModel()
         qDeleteAll(list);
     }
     m_childEntities.clear();
-    m_rootNode = 0;
+    m_rootNode = nullptr;
 
     q->endResetModel();
     fillModel();
@@ -1893,7 +1893,8 @@ void EntityTreeModelPrivate::fillModel()
         CollectionFetchJob *rootFetchJob = new CollectionFetchJob(m_rootCollection, CollectionFetchJob::Base, m_session);
         q->connect(rootFetchJob, SIGNAL(result(KJob*)),
                    SLOT(rootFetchJobDone(KJob*)));
-        qCDebug(DebugETM) << ""; jobTimeTracker[rootFetchJob].start();
+        qCDebug(DebugETM) << "";
+        jobTimeTracker[rootFetchJob].start();
     }
 }
 
