@@ -114,7 +114,8 @@ bool ItemModel::Private::collectionIsCompatible() const
     }
     // if the model's mime types are more specific, limit to those
     // collections that have matching types
-    Q_FOREACH (const QString &type, mParent->mimeTypes()) {
+    const QStringList lstMimetypes = mParent->mimeTypes();
+    for (const QString &type : lstMimetypes ) {
         if (collection.contentMimeTypes().contains(type)) {
             return true;
         }
@@ -218,7 +219,7 @@ void ItemModel::Private::itemsAdded(const Akonadi::Item::List &list)
         return;
     }
     mParent->beginInsertRows(QModelIndex(), items.count(), items.count() + list.count() - 1);
-    foreach (const Item &item, list) {
+    for (const Item &item : list) {
         ItemContainer *c = new ItemContainer(item, items.count());
         items.append(c);
         itemHash[item] = c;
@@ -228,8 +229,7 @@ void ItemModel::Private::itemsAdded(const Akonadi::Item::List &list)
 
 void ItemModel::Private::itemAdded(const Akonadi::Item &item)
 {
-    Item::List l;
-    l << item;
+    const Item::List l = {item};
     itemsAdded(l);
 }
 
@@ -430,7 +430,7 @@ QMimeData *ItemModel::mimeData(const QModelIndexList &indexes) const
     QMimeData *data = new QMimeData();
     // Add item uri to the mimedata for dropping in external applications
     QList<QUrl> urls;
-    foreach (const QModelIndex &index, indexes) {
+    for (const QModelIndex &index : indexes) {
         if (index.column() != 0) {
             continue;
         }
