@@ -31,8 +31,8 @@
 using namespace Akonadi;
 
 TagModelPrivate::TagModelPrivate(TagModel *parent)
-    : mMonitor(0)
-    , mSession(0)
+    : mMonitor(nullptr)
+    , mSession(nullptr)
     , q_ptr(parent)
 {
     // Root tag
@@ -129,7 +129,7 @@ void TagModelPrivate::monitoredTagAdded(const Tag &tag)
     // If there are any child tags waiting for this parent, insert them
     if (mPendingTags.contains(tag.id())) {
         const Tag::List pendingChildren = mPendingTags.take(tag.id());
-        Q_FOREACH (const Tag &pendingTag, pendingChildren) {
+        for (const Tag &pendingTag : pendingChildren) {
             monitoredTagAdded(pendingTag);
         }
     }
@@ -141,7 +141,7 @@ void TagModelPrivate::removeTagsRecursively(qint64 tagId)
 
     // Remove all children first
     const Tag::List childTags = mChildTags.take(tagId);
-    Q_FOREACH (const Tag &child, childTags) {
+    for (const Tag &child : childTags) {
         removeTagsRecursively(child.id());
     }
 
@@ -220,7 +220,7 @@ void TagModelPrivate::monitoredTagChanged(const Tag &tag)
 
 void TagModelPrivate::tagsFetched(const Tag::List &tags)
 {
-    Q_FOREACH (const Tag &tag, tags) {
+    for (const Tag &tag : tags) {
         monitoredTagAdded(tag);
     }
 }
