@@ -119,7 +119,7 @@ public:
      *
      * @param parent The parent object.
      */
-    explicit Monitor(QObject *parent = Q_NULLPTR);
+    explicit Monitor(QObject *parent = nullptr);
 
     /**
      * Destroys the monitor.
@@ -811,7 +811,7 @@ protected:
     friend class EntityTreeModel;
     friend class EntityTreeModelPrivate;
     MonitorPrivate *d_ptr;
-    explicit Monitor(MonitorPrivate *d, QObject *parent = Q_NULLPTR);
+    explicit Monitor(MonitorPrivate *d, QObject *parent = nullptr);
     //@endcond
 
 private:
