@@ -19,6 +19,7 @@
 
 #include "session.h"
 #include "session_p.h"
+#include "helper_p.h"
 
 #include "job.h"
 #include "job_p.h"
@@ -34,15 +35,10 @@
 #include <KLocalizedString>
 
 #include <QCoreApplication>
-#include <QDir>
-#include <QQueue>
 #include <QThreadStorage>
 #include <QTimer>
 #include <QThread>
-#include <QSettings>
 
-#include <QLocalSocket>
-#include <QTcpSocket>
 #include <QHostAddress>
 #include <QApplication>
 
@@ -100,7 +96,7 @@ void SessionPrivate::socketDisconnected()
 
 bool SessionPrivate::handleCommand(qint64 tag, const Protocol::Command &cmd)
 {
-   // Handle Hello response -> send Login
+    // Handle Hello response -> send Login
     if (cmd.type() == Protocol::Command::Hello) {
         Protocol::HelloResponse hello(cmd);
         if (hello.isError()) {
@@ -119,7 +115,6 @@ bool SessionPrivate::handleCommand(qint64 tag, const Protocol::Command &cmd)
         Internal::setServerProtocolVersion(protocolVersion);
         Internal::setGeneration(hello.generation());
 
-
         Protocol::LoginCommand login(sessionId);
         sendCommand(nextTag(), login);
         return true;
@@ -193,13 +188,13 @@ void SessionPrivate::startJob(Job *job)
                                    "If you updated your system recently please restart the Akonadi server.",
                                    protocolVersion, Protocol::version()));
             qCWarning(AKONADICORE_LOG) << "Protocol version mismatch. Server version is newer (" << protocolVersion << ") than ours (" << Protocol::version() << "). "
-                       "If you updated your system recently please restart the Akonadi server.";
+                                       "If you updated your system recently please restart the Akonadi server.";
         } else {
             job->setErrorText(i18n("Protocol version mismatch. Server version is older (%1) than ours (%2). "
                                    "If you updated your system recently please restart all KDE PIM applications.",
                                    protocolVersion, Protocol::version()));
             qCWarning(AKONADICORE_LOG) << "Protocol version mismatch. Server version is older (" << protocolVersion << ") than ours (" << Protocol::version() << "). "
-                       "If you updated your system recently please restart all KDE PIM applications.";
+                                       "If you updated your system recently please restart all KDE PIM applications.";
         }
         job->emitResult();
     } else {
@@ -219,7 +214,7 @@ void SessionPrivate::jobDone(KJob *job)
     if (job == currentJob) {
         if (pipeline.isEmpty()) {
             jobRunning = false;
-            currentJob = 0;
+            currentJob = nullptr;
         } else {
             currentJob = pipeline.dequeue();
         }
@@ -272,13 +267,13 @@ void SessionPrivate::serverStateChanged(ServerManager::State state)
     } else if (!connected && state == ServerManager::Broken) {
         // If the server is broken, cancel all pending jobs, otherwise they will be
         // blocked forever and applications waiting for them to finish would be stuck
-        Q_FOREACH (Job *job, queue) {
+        for (Job *job : qAsConst(queue)) {
             job->setError(Job::ConnectionFailed);
             job->kill(KJob::EmitResult);
         }
     } else if (state == ServerManager::Stopping) {
         delete connection;
-        connection = Q_NULLPTR;
+        connection = nullptr;
     }
 }
 
@@ -286,7 +281,7 @@ void SessionPrivate::itemRevisionChanged(Akonadi::Item::Id itemId, int oldRevisi
 {
     // only deal with the queue, for the guys in the pipeline it's too late already anyway
     // and they shouldn't have gotten there if they depend on a preceding job anyway.
-    Q_FOREACH (Job *job, queue) {
+    for (Job *job : qAsConst(queue)) {
         job->d_ptr->updateItemRevision(itemId, oldRevision, newRevision);
     }
 }
@@ -296,18 +291,18 @@ void SessionPrivate::itemRevisionChanged(Akonadi::Item::Id itemId, int oldRevisi
 SessionPrivate::SessionPrivate(Session *parent)
     : mParent(parent)
     , mSessionThread(new SessionThread)
-    , connection(Q_NULLPTR)
+    , connection(nullptr)
     , protocolVersion(0)
-    , currentJob(Q_NULLPTR)
+    , currentJob(nullptr)
 {
     // Shutdown the thread before QApplication event loop quits - the
     // thread()->wait() mechanism in Connection dtor crashes sometimes
     // when called from QApplication destructor
     connThreadCleanUp = QObject::connect(qApp, &QCoreApplication::aboutToQuit,
-                                         [this]() {
-                                             delete mSessionThread;
-                                             mSessionThread = Q_NULLPTR;
-                                         });
+    [this]() {
+        delete mSessionThread;
+        mSessionThread = nullptr;
+    });
 }
 
 SessionPrivate::~SessionPrivate()
@@ -379,7 +374,7 @@ Q_GLOBAL_STATIC(QThreadStorage<Session *>, instances)
 
 static void cleanupDefaultSession()
 {
-    instances()->setLocalData(Q_NULLPTR);
+    instances()->setLocalData(nullptr);
 }
 
 void SessionPrivate::createDefaultSession(const QByteArray &sessionId)
@@ -411,11 +406,11 @@ Session *Session::defaultSession()
 
 void Session::clear()
 {
-    Q_FOREACH(Job *job, d->queue) {
+    for (Job *job : qAsConst(d->queue)) {
         job->kill(KJob::EmitResult);   // safe, not started yet
     }
     d->queue.clear();
-    Q_FOREACH(Job *job, d->pipeline) {
+    for (Job *job : qAsConst(d->pipeline)) {
         job->d_ptr->mStarted = false; // avoid killing/reconnect loops
         job->kill(KJob::EmitResult);
     }
