@@ -21,14 +21,17 @@
 #include "storage/datastore.h"
 #include "storage/selectquerybuilder.h"
 #include "akonadiserver_debug.h"
-
+#include "utils.h"
 #include <private/tristate_p.h>
 
 #include <QDateTime>
 #include <QCoreApplication>
+#include <QTimer>
 
-namespace Akonadi {
-namespace Server {
+namespace Akonadi
+{
+namespace Server
+{
 
 /**
  * @warning: QTimer's methods are not virtual, so it's necessary to always call
@@ -39,7 +42,7 @@ class PauseableTimer : public QTimer
     Q_OBJECT
 
 public:
-    PauseableTimer(QObject *parent = Q_NULLPTR)
+    PauseableTimer(QObject *parent = nullptr)
         : QTimer(parent)
     {
     }
@@ -102,9 +105,9 @@ private:
 
 using namespace Akonadi::Server;
 
-CollectionScheduler::CollectionScheduler(QThread::Priority priority, QObject *parent)
-    : AkThread(priority, parent)
-    , mScheduler(Q_NULLPTR)
+CollectionScheduler::CollectionScheduler(const QString &threadName, QThread::Priority priority, QObject *parent)
+    : AkThread(threadName, priority, parent)
+    , mScheduler(nullptr)
     , mMinInterval(5)
 {
 }
@@ -116,6 +119,7 @@ CollectionScheduler::~CollectionScheduler()
 void CollectionScheduler::quit()
 {
     delete mScheduler;
+    mScheduler = nullptr;
 
     AkThread::quit();
 }
@@ -155,7 +159,7 @@ void CollectionScheduler::collectionAdded(qint64 collectionId)
 void CollectionScheduler::collectionChanged(qint64 collectionId)
 {
     QMutexLocker locker(&mScheduleLock);
-    Q_FOREACH (const Collection &collection, mSchedule) {
+    for (const Collection &collection : qAsConst(mSchedule)) {
         if (collection.id() == collectionId) {
             Collection changed = Collection::retrieveById(collectionId);
             DataStore::self()->activeCachePolicy(changed);
@@ -182,7 +186,7 @@ void CollectionScheduler::collectionChanged(qint64 collectionId)
 void CollectionScheduler::collectionRemoved(qint64 collectionId)
 {
     QMutexLocker locker(&mScheduleLock);
-    Q_FOREACH (const Collection &collection, mSchedule) {
+    for (const Collection &collection : qAsConst(mSchedule)) {
         if (collection.id() == collectionId) {
             const uint key = mSchedule.key(collection);
             const bool reschedule = (key == mSchedule.constBegin().key());
@@ -285,7 +289,7 @@ void CollectionScheduler::init()
     }
 
     const Collection::List collections = qb.result();
-    Q_FOREACH (const Collection &collection, collections) {
+    for (const Collection &collection : collections) {
         scheduleCollection(collection);
     }
 
@@ -303,7 +307,7 @@ void CollectionScheduler::schedulerTimeout()
     mSchedule.remove(timestamp);
     mScheduleLock.unlock();
 
-    Q_FOREACH (const Collection &collection, collections) {
+    for (const Collection &collection : collections) {
         collectionExpired(collection);
         scheduleCollection(collection, false);
     }
