@@ -20,9 +20,9 @@
 #include "connection.h"
 #include "akonadiserver_debug.h"
 
-#include <QEventLoop>
 #include <QLatin1String>
 #include <QSettings>
+#include <QDataStream>
 
 #include "storage/datastore.h"
 #include "handler.h"
@@ -38,24 +38,29 @@
 #include <private/datastream_p_p.h>
 #include <private/standarddirs_p.h>
 
-
 using namespace Akonadi;
 using namespace Akonadi::Server;
 
 #define IDLE_TIMER_TIMEOUT 180000 // 3 min
 
+static QString connectionIdentifier(Connection *c) {
+    QString id;
+    id.sprintf("%p", static_cast<void *>(c));
+    return id;
+}
+
 Connection::Connection(QObject *parent)
-    : AkThread(QThread::InheritPriority, parent)
+    : AkThread(connectionIdentifier(this), QThread::InheritPriority, parent)
     , m_socketDescriptor(0)
-    , m_socket(0)
-    , m_currentHandler(0)
+    , m_socket(nullptr)
+    , m_currentHandler(nullptr)
     , m_connectionState(NonAuthenticated)
-    , m_backend(0)
+    , m_backend(nullptr)
     , m_verifyCacheOnRetrieval(false)
-    , m_idleTimer(Q_NULLPTR)
-    , m_totalTime( 0 )
+    , m_idleTimer(nullptr)
+    , m_totalTime(0)
     , m_connectionClosing(false)
-    , m_reportTime( false )
+    , m_reportTime(false)
 {
 }
 
@@ -63,8 +68,7 @@ Connection::Connection(quintptr socketDescriptor, QObject *parent)
     : Connection(parent)
 {
     m_socketDescriptor = socketDescriptor;
-    m_identifier.sprintf("%p", static_cast<void *>(this));
-    setObjectName(m_identifier);
+    m_identifier = connectionIdentifier(this); // same as objectName()
 
     const QSettings settings(Akonadi::StandardDirs::serverConfigFile(), QSettings::IniFormat);
     m_verifyCacheOnRetrieval = settings.value(QStringLiteral("Cache/VerifyOnRetrieval"), m_verifyCacheOnRetrieval).toBool();
@@ -78,8 +82,8 @@ void Connection::init()
 
     if (!socket->setSocketDescriptor(m_socketDescriptor)) {
         qCWarning(AKONADISERVER_LOG) << "Connection(" << m_identifier
-                   << ")::run: failed to set socket descriptor: "
-                   << socket->error() << "(" << socket->errorString() << ")";
+                                     << ")::run: failed to set socket descriptor: "
+                                     << socket->error() << "(" << socket->errorString() << ")";
         delete socket;
         return;
     }
@@ -119,7 +123,7 @@ void Connection::quit()
     collectionReferenceManager()->removeSession(m_sessionId);
 
     delete m_socket;
-    m_socket = 0;
+    m_socket = nullptr;
 
     m_idleTimer->stop();
     delete m_idleTimer;
@@ -163,8 +167,8 @@ Connection::~Connection()
 
 void Connection::slotConnectionIdle()
 {
-    Q_ASSERT(m_currentHandler == Q_NULLPTR);
-    if (m_backend && m_backend->isOpened() ) {
+    Q_ASSERT(m_currentHandler == nullptr);
+    if (m_backend && m_backend->isOpened()) {
         if (m_backend->inTransaction()) {
             // This is a programming error, the timer should not have fired.
             // But it is safer to abort and leave the connection open, until
@@ -282,7 +286,7 @@ void Connection::slotNewData()
             stopTime(currentCommand);
         }
         delete m_currentHandler;
-        m_currentHandler = 0;
+        m_currentHandler = nullptr;
 
         if (m_socket->state() != QLocalSocket::ConnectedState) {
             Q_EMIT disconnected();
@@ -356,6 +360,8 @@ void Connection::setSessionId(const QByteArray &id)
 
     m_sessionId = id;
     setObjectName(QString::fromLatin1(id));
+    // this races with the use of objectName() in QThreadPrivate::start
+    //thread()->setObjectName(objectName() + QStringLiteral("-Thread"));
     storageBackend()->setSessionId(id);
     storageBackend()->notificationCollector()->setSessionId(id);
 }
@@ -404,7 +410,7 @@ void Connection::stopTime(const QString &identifier)
     m_totalTime += elapsed;
     m_totalTimeByHandler[identifier] += elapsed;
     m_executionsByHandler[identifier]++;
-    qCDebug(AKONADISERVER_LOG) << identifier <<" time : " << elapsed << " total: " << m_totalTime;
+    qCDebug(AKONADISERVER_LOG) << identifier << " time : " << elapsed << " total: " << m_totalTime;
 }
 
 void Connection::reportTime() const
@@ -413,7 +419,7 @@ void Connection::reportTime() const
     qCDebug(AKONADISERVER_LOG) << " total: " << m_totalTime;
     for (auto it = m_totalTimeByHandler.cbegin(), end = m_totalTimeByHandler.cend(); it != end; ++it) {
         const QString &handler = it.key();
-        qCDebug(AKONADISERVER_LOG) << "handler : " << handler << " time: " << m_totalTimeByHandler.value(handler) << " executions " << m_executionsByHandler.value(handler) << " avg: " << m_totalTimeByHandler.value(handler)/m_executionsByHandler.value(handler);
+        qCDebug(AKONADISERVER_LOG) << "handler : " << handler << " time: " << m_totalTimeByHandler.value(handler) << " executions " << m_executionsByHandler.value(handler) << " avg: " << m_totalTimeByHandler.value(handler) / m_executionsByHandler.value(handler);
     }
 }
 
