@@ -24,7 +24,7 @@
 #include <QThread>
 #include <QTimer>
 #include <QLocalSocket>
-#include <QDataStream>
+#include <QTime>
 
 #include "akthread.h"
 #include "entities.h"
@@ -33,8 +33,10 @@
 
 #include <private/protocol_p.h>
 
-namespace Akonadi {
-namespace Server {
+namespace Akonadi
+{
+namespace Server
+{
 
 class Handler;
 class Response;
@@ -49,7 +51,7 @@ class Connection : public AkThread
 {
     Q_OBJECT
 public:
-    explicit Connection(quintptr socketDescriptor, QObject *parent = Q_NULLPTR);
+    explicit Connection(quintptr socketDescriptor, QObject *parent = nullptr);
     virtual ~Connection();
 
     virtual DataStore *storageBackend();
@@ -90,7 +92,7 @@ protected Q_SLOTS:
     void slotSendHello();
 
 protected:
-    Connection(QObject *parent = Q_NULLPTR); // used for testing
+    Connection(QObject *parent = nullptr); // used for testing
 
     virtual void init() Q_DECL_OVERRIDE;
     virtual void quit() Q_DECL_OVERRIDE;
@@ -131,6 +133,4 @@ private:
 } // namespace Server
 } // namespace Akonadi
 
-
-
 #endif
