@@ -21,11 +21,13 @@
 #define AKONADI_FILETRACER_H
 
 #include "tracerinterface.h"
-
+#include <QObject>
 class QFile;
 
-namespace Akonadi {
-namespace Server {
+namespace Akonadi
+{
+namespace Server
+{
 
 /**
  * A tracer which forwards all tracing information to a
@@ -37,13 +39,13 @@ public:
     explicit FileTracer(const QString &fileName);
     virtual ~FileTracer();
 
-    virtual void beginConnection(const QString &identifier, const QString &msg);
-    virtual void endConnection(const QString &identifier, const QString &msg);
-    virtual void connectionInput(const QString &identifier, const QByteArray &msg);
-    virtual void connectionOutput(const QString &identifier, const QByteArray &msg);
-    virtual void signal(const QString &signalName, const QString &msg);
-    virtual void warning(const QString &componentName, const QString &msg);
-    virtual void error(const QString &componentName, const QString &msg);
+    void beginConnection(const QString &identifier, const QString &msg) Q_DECL_OVERRIDE;
+    void endConnection(const QString &identifier, const QString &msg) Q_DECL_OVERRIDE;
+    void connectionInput(const QString &identifier, const QByteArray &msg) Q_DECL_OVERRIDE;
+    void connectionOutput(const QString &identifier, const QByteArray &msg) Q_DECL_OVERRIDE;
+    void signal(const QString &signalName, const QString &msg) Q_DECL_OVERRIDE;
+    void warning(const QString &componentName, const QString &msg) Q_DECL_OVERRIDE;
+    void error(const QString &componentName, const QString &msg) Q_DECL_OVERRIDE;
 
 private:
     void output(const QString &id, const QString &msg);
