@@ -36,18 +36,15 @@
 #include "dbusconnectionpool.h"
 #include "tagfetchhelper.h"
 #include "relationfetch.h"
+#include "utils.h"
 #include "akonadiserver_debug.h"
 
 #include <private/scope_p.h>
 #include <private/dbus_p.h>
 
-#include <QLocale>
 #include <QStringList>
-#include <QUuid>
 #include <QVariant>
 #include <QDateTime>
-#include <QSqlDatabase>
-#include <QSqlError>
 #include <QSqlQuery>
 
 #include <QElapsedTimer>
@@ -57,18 +54,18 @@ using namespace Akonadi::Server;
 
 #define ENABLE_FETCH_PROFILING 0
 #if ENABLE_FETCH_PROFILING
-    #define BEGIN_TIMER(name) \
-        QElapsedTimer name##Timer; \
-        name##Timer.start();
+#define BEGIN_TIMER(name) \
+    QElapsedTimer name##Timer; \
+    name##Timer.start();
 
-    #define END_TIMER(name) \
-        const double name##Elapsed = name##Timer.nsecsElapsed() / 1000000.0;
-    #define PROF_INC(name) \
-        ++name;
+#define END_TIMER(name) \
+    const double name##Elapsed = name##Timer.nsecsElapsed() / 1000000.0;
+#define PROF_INC(name) \
+    ++name;
 #else
-    #define BEGIN_TIMER(name)
-    #define END_TIMER(name)
-    #define PROF_INC(name)
+#define BEGIN_TIMER(name)
+#define END_TIMER(name)
+#define PROF_INC(name)
 #endif
 
 FetchHelper::FetchHelper(Connection *connection, const Scope &scope,
@@ -107,7 +104,7 @@ QSqlQuery FetchHelper::buildPartQuery(const QVector<QByteArray> &partList, bool
 
         if (!partList.isEmpty() || allPayload || allAttrs) {
             Query::Condition cond(Query::Or);
-            Q_FOREACH (const QByteArray &b, partList) {
+            for (const QByteArray &b : qAsConst(partList)) {
                 if (b.startsWith("PLD") || b.startsWith("ATR")) {
                     cond.addValueCondition(Part::partTypeIdFullColumnName(), Query::Equals, PartTypeHelper::fromFqName(b).id());
                 }
@@ -296,8 +293,8 @@ bool FetchHelper::isScopeLocal(const Scope &scope)
     const QString resourceName = query.value(0).toString();
 
     org::freedesktop::Akonadi::AgentManager manager(DBus::serviceName(DBus::Control),
-                                                    QStringLiteral("/AgentManager"),
-                                                    DBusConnectionPool::threadConnection());
+            QStringLiteral("/AgentManager"),
+            DBusConnectionPool::threadConnection());
     const QString typeIdentifier = manager.agentInstanceType(resourceName);
     const QVariantMap properties = manager.agentCustomProperties(typeIdentifier);
     return properties.value(QStringLiteral("HasLocalStorage"), false).toBool();
@@ -316,13 +313,13 @@ bool FetchHelper::fetchItems()
     // messages, not all of them. In the long term, we need a better way to do this.
     BEGIN_TIMER(itemRetriever)
     BEGIN_TIMER(scopeLocal)
-    #if ENABLE_FETCH_PROFILING
+#if ENABLE_FETCH_PROFILING
     double scopeLocalElapsed = 0;
-    #endif
+#endif
     if (!mFetchScope.cacheOnly() || isScopeLocal(mScope)) {
-        #if ENABLE_FETCH_PROFILING
+#if ENABLE_FETCH_PROFILING
         scopeLocalElapsed = scopeLocalTimer.elapsed();
-        #endif
+#endif
 
         // trigger a collection sync if configured to do so
         triggerOnDemandFetch();
@@ -401,13 +398,13 @@ bool FetchHelper::fetchItems()
     }
     END_TIMER(vRefs)
 
-    #if ENABLE_FETCH_PROFILING
+#if ENABLE_FETCH_PROFILING
     int itemsCount = 0;
     int flagsCount = 0;
     int partsCount = 0;
     int tagsCount = 0;
     int vRefsCount = 0;
-    #endif
+#endif
 
     BEGIN_TIMER(processing)
     QHash<qint64, QByteArray> flagIdNameCache;
@@ -486,11 +483,11 @@ bool FetchHelper::fetchItems()
 
             tags.reserve(tagIds.count());
             if (!fullTagsRequested) {
-                Q_FOREACH (qint64 tagId, tagIds) {
+                for (qint64 tagId : qAsConst(tagIds)) {
                     tags << Protocol::FetchTagsResponse(tagId);
                 }
             } else {
-                Q_FOREACH (qint64 tagId, tagIds) {
+                for (qint64 tagId : qAsConst(tagIds)) {
                     tags << HandlerHelper::fetchTagsResponse(Tag::retrieveById(tagId));
                 }
             }
@@ -528,7 +525,7 @@ bool FetchHelper::fetchItems()
             QVector<Protocol::FetchRelationsResponse> relations;
             const auto result = qb.result();
             relations.reserve(result.size());
-            Q_FOREACH (const Relation &rel, result) {
+            for (const Relation &rel : result) {
                 relations << HandlerHelper::fetchRelationsResponse(rel);
             }
             response.setRelations(relations);
@@ -618,7 +615,7 @@ bool FetchHelper::fetchItems()
     END_TIMER(aTime)
 
     END_TIMER(fetch)
-    #if ENABLE_FETCH_PROFILING
+#if ENABLE_FETCH_PROFILING
     qCDebug(AKONADISERVER_LOG) << "FetchHelper execution stats:";
     qCDebug(AKONADISERVER_LOG) << "\tItems query:" << itemsElapsed << "ms," << itemsCount << " items in total";
     qCDebug(AKONADISERVER_LOG) << "\tFlags query:" << flagsElapsed << "ms, " << flagsCount << " flags in total";
@@ -634,7 +631,7 @@ bool FetchHelper::fetchItems()
     qCDebug(AKONADISERVER_LOG) << "\tTotal FETCH:" << fetchElapsed << "ms";
     qCDebug(AKONADISERVER_LOG);
     qCDebug(AKONADISERVER_LOG);
-    #endif
+#endif
 
     return true;
 }
@@ -650,7 +647,7 @@ bool FetchHelper::needsAccessTimeUpdate(const QVector<QByteArray> &parts)
 
 void FetchHelper::updateItemAccessTime()
 {
-    Transaction transaction(mConnection->storageBackend());
+    Transaction transaction(mConnection->storageBackend(), QStringLiteral("update atime"));
     QueryBuilder qb(PimItem::tableName(), QueryBuilder::Update);
     qb.setColumnValue(PimItem::atimeColumn(), QDateTime::currentDateTimeUtc());
     ItemQueryHelper::scopeToQuery(mScope, mConnection->context(), qb);
@@ -712,6 +709,7 @@ QVector<Protocol::Ancestor> FetchHelper::ancestorsForItem(Collection::Id parentC
 
 QVariant FetchHelper::extractQueryResult(const QSqlQuery &query, FetchHelper::ItemQueryColumns column) const
 {
-    Q_ASSERT(mItemQueryColumnMap[column] >= 0);
-    return query.value(mItemQueryColumnMap[column]);
+    const int colId = mItemQueryColumnMap[column];
+    Q_ASSERT(colId >= 0);
+    return query.value(colId);
 }
