@@ -20,7 +20,6 @@
 #ifndef AKONADI_FETCHHELPER_H
 #define AKONADI_FETCHHELPER_H
 
-#include <QStack>
 
 #include "storage/countquerybuilder.h"
 #include "storage/datastore.h"
@@ -32,12 +31,13 @@
 
 class FetchHelperTest;
 
-namespace Akonadi {
+namespace Akonadi
+{
 
-namespace Server {
+namespace Server
+{
 
 class Connection;
-class Response;
 
 class FetchHelper : public QObject
 {
