@@ -20,6 +20,7 @@
 #include "list.h"
 #include "akonadiserver_debug.h"
 
+#include "utils.h"
 #include "connection.h"
 #include "handlerhelper.h"
 #include "collectionreferencemanager.h"
@@ -35,7 +36,7 @@ using namespace Akonadi::Server;
 template <typename T>
 static bool intersect(const QVector<typename T::Id> &l1, const QVector<T> &l2)
 {
-    Q_FOREACH (const T &e2, l2) {
+    for (const T &e2 : l2) {
         if (l1.contains(e2.id())) {
             return true;
         }
@@ -122,7 +123,7 @@ void List::listCollection(const Collection &root, const QStack<Collection> &ance
     //backwards compatibility, collectionToByteArray will automatically fall-back to id + remoteid
     if (!mAncestorAttributes.isEmpty()) {
         ancestorAttributes.reserve(ancestors.size());
-        Q_FOREACH (const Collection &col, ancestors) {
+        for (const Collection &col : ancestors) {
             ancestorAttributes.push(getAttributes(col, mAncestorAttributes));
         }
     }
@@ -133,10 +134,10 @@ void List::listCollection(const Collection &root, const QStack<Collection> &ance
     db->activeCachePolicy(dummy);
 
     sendResponse(HandlerHelper::fetchCollectionsResponse(dummy, attributes, mIncludeStatistics,
-                                                         mAncestorDepth, ancestors,
-                                                         ancestorAttributes,
-                                                         isReferencedFromSession || resourceIsSynchronizing,
-                                                         mimeTypes));
+                 mAncestorDepth, ancestors,
+                 ancestorAttributes,
+                 isReferencedFromSession || resourceIsSynchronizing,
+                 mimeTypes));
 }
 
 static Query::Condition filterCondition(const QString &column)
@@ -159,19 +160,19 @@ bool List::checkFilterCondition(const Collection &col) const
     }
     //Don't include the collection when only looking for collections to display/index/sync
     if (mCollectionsToDisplay &&
-        (((col.displayPref() == Tristate::Undefined) && !col.enabled()) ||
-         (col.displayPref() == Tristate::False))) {
+            (((col.displayPref() == Tristate::Undefined) && !col.enabled()) ||
+             (col.displayPref() == Tristate::False))) {
         return false;
     }
     if (mCollectionsToIndex &&
-        (((col.indexPref() == Tristate::Undefined) && !col.enabled()) ||
-         (col.indexPref() == Tristate::False))) {
+            (((col.indexPref() == Tristate::Undefined) && !col.enabled()) ||
+             (col.indexPref() == Tristate::False))) {
         return false;
     }
     //Single collection sync will still work since that is using a base fetch
     if (mCollectionsToSynchronize &&
-        (((col.syncPref() == Tristate::Undefined) && !col.enabled()) ||
-         (col.syncPref() == Tristate::False))) {
+            (((col.syncPref() == Tristate::Undefined) && !col.enabled()) ||
+             (col.syncPref() == Tristate::False))) {
         return false;
     }
     return true;
@@ -190,17 +191,17 @@ static QSqlQuery getAttributeQuery(const QVariantList &ids, const QSet<QByteArra
     if (!requestedAttributes.isEmpty()) {
         QVariantList attributes;
         attributes.reserve(requestedAttributes.size());
-        Q_FOREACH (const QByteArray &type, requestedAttributes) {
+        for (const QByteArray &type : requestedAttributes) {
             attributes << type;
         }
         qb.addValueCondition(CollectionAttribute::typeFullColumnName(), Query::In, attributes);
-        }
+    }
 
     qb.addSortColumn(CollectionAttribute::collectionIdFullColumnName(), Query::Ascending);
 
     if (!qb.exec()) {
         throw HandlerException("Unable to retrieve attributes for listing");
-            }
+    }
     return qb.query();
 }
 
@@ -220,8 +221,8 @@ void List::retrieveAttributes(const QVariantList &collectionIds)
             mCollectionAttributes.insert(attributeQuery.value(0).toLongLong(), attr);
         }
         start += size;
-        }
     }
+}
 
 static QSqlQuery getMimeTypeQuery(const QVariantList &ids)
 {
@@ -249,8 +250,8 @@ void List::retrieveCollections(const Collection &topParent, int depth)
      * * First all collections that match the given criteria are queried
      * * We then filter the false positives:
      * ** all collections out that are not part of the tree we asked for are filtered
-     * ** all collections that are referenced but not by this session or by the owning resource are filtered 
-     * * Finally we complete the tree by adding missing collections 
+     * ** all collections that are referenced but not by this session or by the owning resource are filtered
+     * * Finally we complete the tree by adding missing collections
      *
      * Mimetypes and attributes are also retrieved in single queries to avoid spawning two queries per collection (the N+1 problem).
      * Note that we're not querying attributes and mimetypes for the collections that are only included to complete the tree,
@@ -282,7 +283,7 @@ void List::retrieveCollections(const Collection &topParent, int depth)
             if (mCollectionsToSynchronize) {
                 qb.addCondition(filterCondition(Collection::syncPrefFullColumnName()));
             } else if (mCollectionsToDisplay) {
-                    qCDebug(AKONADISERVER_LOG) << "only display";
+                qCDebug(AKONADISERVER_LOG) << "only display";
                 qb.addCondition(filterCondition(Collection::displayPrefFullColumnName()));
             } else if (mCollectionsToIndex) {
                 qb.addCondition(filterCondition(Collection::indexPrefFullColumnName()));
@@ -300,7 +301,7 @@ void List::retrieveCollections(const Collection &topParent, int depth)
                 qb.addJoin(QueryBuilder::LeftJoin, CollectionMimeTypeRelation::tableName(), CollectionMimeTypeRelation::leftColumn(), Collection::idFullColumnName());
                 QVariantList mimeTypeFilter;
                 mimeTypeFilter.reserve(mMimeTypes.size());
-                Q_FOREACH(MimeType::Id mtId, mMimeTypes) {
+                for (MimeType::Id mtId : qAsConst(mMimeTypes)) {
                     mimeTypeFilter << mtId;
                 }
                 qb.addValueCondition(CollectionMimeTypeRelation::rightColumn(), Query::In, mimeTypeFilter);
@@ -393,12 +394,12 @@ void List::retrieveCollections(const Collection &topParent, int depth)
 
     QSet<qint64> missingCollections;
     if (depth > 0) {
-        Q_FOREACH (const Collection &col, mCollections) {
+        for (const Collection &col : qAsConst(mCollections)) {
             if (col.parentId() != parentId && !mCollections.contains(col.parentId())) {
-            missingCollections.insert(col.parentId());
+                missingCollections.insert(col.parentId());
+            }
         }
     }
-    }
 
     /*
     QSet<qint64> knownIds;
@@ -414,7 +415,7 @@ void List::retrieveCollections(const Collection &topParent, int depth)
         SelectQueryBuilder<Collection> qb;
         QVariantList ids;
         ids.reserve(missingCollections.size());
-        Q_FOREACH (qint64 id, missingCollections) {
+        for (qint64 id : qAsConst(missingCollections)) {
             ids << id;
         }
         qb.addValueCondition(Collection::idFullColumnName(), Query::In, ids);
@@ -522,7 +523,8 @@ bool List::parseStream()
             return failureResponse("Unknown resource");
         }
     }
-    Q_FOREACH (const QString &mtName, cmd.mimeTypes()) {
+    const QStringList lstMimeTypes = cmd.mimeTypes();
+    for (const QString &mtName : lstMimeTypes) {
         const MimeType mt = MimeType::retrieveByNameOrCreate(mtName);
         if (!mt.isValid()) {
             return failureResponse("Failed to create mimetype record");
@@ -611,7 +613,7 @@ bool List::parseStream()
     } else { //Root folder listing
         if (depth != 0) {
             retrieveCollections(Collection(), depth);
-    }
+        }
     }
 
     return successResponse<Protocol::FetchCollectionsResponse>();
