@@ -49,7 +49,7 @@ bool Modify::parseStream()
     if (cmd.modifiedParts() & Protocol::ModifyCollectionCommand::ParentID) {
         const Collection newParent = Collection::retrieveById(cmd.parentId());
         if (newParent.isValid() && collection.parentId() != newParent.id()
-            && collection.resourceId() != newParent.resourceId()) {
+                && collection.resourceId() != newParent.resourceId()) {
             inhibitor.inhibit();
             ItemRetriever retriever(connection());
             retriever.setCollection(collection, true);
@@ -61,7 +61,7 @@ bool Modify::parseStream()
     }
 
     DataStore *db = connection()->storageBackend();
-    Transaction transaction(db);
+    Transaction transaction(db, QStringLiteral("MODIFY"));
     QList<QByteArray> changes;
     bool referencedChanged = false;
 
@@ -69,9 +69,9 @@ bool Modify::parseStream()
         QStringList mts = cmd.mimeTypes();
         const MimeType::List currentMts = collection.mimeTypes();
         bool equal = true;
-        Q_FOREACH (const MimeType &currentMt, currentMts) {
-            if (mts.contains(currentMt.name())) {
-                mts.removeAll(currentMt.name());
+        for (const MimeType &currentMt : currentMts) {
+            const int removeMts = mts.removeAll(currentMt.name());
+            if (removeMts > 0) {
                 continue;
             }
             equal = false;
@@ -139,7 +139,6 @@ bool Modify::parseStream()
         }
     }
 
-
     if (cmd.modifiedParts() & Protocol::ModifyCollectionCommand::RemoteID) {
         if (cmd.remoteId() != collection.remoteId()) {
             if (!connection()->isOwnerResource(collection)) {
@@ -182,7 +181,7 @@ bool Modify::parseStream()
             changed = true;
         }
         if (changed) {
-            collection.setQueryAttributes(QString::fromLatin1(queryAttributes.join(" ")));
+            collection.setQueryAttributes(QString::fromLatin1(queryAttributes.join(' ')));
         }
 
         QStringList cols;
@@ -256,7 +255,6 @@ bool Modify::parseStream()
                 return failureResponse("Unable to retrieve collection attribute");
             }
 
-
             const CollectionAttribute::List attrs = qb.result();
             if (attrs.isEmpty()) {
                 CollectionAttribute newAttr;
