@@ -50,7 +50,7 @@ Collection HandlerHelper::collectionFromIdOrName(const QByteArray &id)
 
     const QStringList pathParts = path.split(QLatin1Char('/'), QString::SkipEmptyParts);
     Collection col;
-    Q_FOREACH (const QString &part, pathParts) {
+    for (const QString &part : pathParts) {
         SelectQueryBuilder<Collection> qb;
         qb.addValueCondition(Collection::nameColumn(), Query::Equals, part);
         if (col.isValid()) {
@@ -78,10 +78,10 @@ QString HandlerHelper::pathForCollection(const Collection &col)
         parts.prepend(current.name());
         current = current.parent();
     }
-    return parts.join(QStringLiteral("/"));
+    return parts.join(QLatin1Char('/'));
 }
 
-Protocol::CachePolicy HandlerHelper::cachePolicyResponse(const Collection& col)
+Protocol::CachePolicy HandlerHelper::cachePolicyResponse(const Collection &col)
 {
     Protocol::CachePolicy cachePolicy;
     cachePolicy.setInherit(col.cachePolicyInherit());
@@ -105,13 +105,13 @@ Protocol::FetchCollectionsResponse HandlerHelper::fetchCollectionsResponse(const
 }
 
 Protocol::FetchCollectionsResponse HandlerHelper::fetchCollectionsResponse(const Collection &col,
-                                                                           const CollectionAttribute::List &attrs,
-                                                                           bool includeStatistics,
-                                                                           int ancestorDepth,
-                                                                           const QStack<Collection> &ancestors,
-                                                                           const QStack<CollectionAttribute::List> &ancestorAttributes,
-                                                                           bool isReferenced,
-                                                                           const QStringList &mimeTypes)
+        const CollectionAttribute::List &attrs,
+        bool includeStatistics,
+        int ancestorDepth,
+        const QStack<Collection> &ancestors,
+        const QStack<CollectionAttribute::List> &ancestorAttributes,
+        bool isReferenced,
+        const QStringList &mimeTypes)
 {
     Protocol::FetchCollectionsResponse response(col.id());
     response.setParentId(col.parentId());
@@ -126,8 +126,8 @@ Protocol::FetchCollectionsResponse HandlerHelper::fetchCollectionsResponse(const
         const CollectionStatistics::Statistics stats = CollectionStatistics::self()->statistics(col);
         if (stats.count > -1) {
             Protocol::FetchCollectionStatsResponse statsResponse(stats.count,
-                                                                 stats.count - stats.read,
-                                                                 stats.size);
+                    stats.count - stats.read,
+                    stats.size);
             response.setStatistics(statsResponse);
         }
     }
@@ -137,7 +137,7 @@ Protocol::FetchCollectionsResponse HandlerHelper::fetchCollectionsResponse(const
         QVector<qint64> searchCols;
         const QStringList searchColIds = col.queryCollections().split(QLatin1Char(' '));
         searchCols.reserve(searchColIds.size());
-        Q_FOREACH (const QString &searchColId, searchColIds) {
+        for (const QString &searchColId : searchColIds) {
             searchCols << searchColId.toLongLong();
         }
         response.setSearchCollections(searchCols);
@@ -168,8 +168,8 @@ Protocol::FetchCollectionsResponse HandlerHelper::fetchCollectionsResponse(const
 }
 
 QVector<Protocol::Ancestor> HandlerHelper::ancestorsResponse(int ancestorDepth,
-                                                             const QStack<Collection> &_ancestors,
-                                                             const QStack<CollectionAttribute::List> &_ancestorsAttributes)
+        const QStack<Collection> &_ancestors,
+        const QStack<CollectionAttribute::List> &_ancestorsAttributes)
 {
     QVector<Protocol::Ancestor> rv;
     if (ancestorDepth  > 0) {
@@ -200,8 +200,8 @@ QVector<Protocol::Ancestor> HandlerHelper::ancestorsResponse(int ancestorDepth,
 }
 
 Protocol::FetchTagsResponse HandlerHelper::fetchTagsResponse(const Tag &tag,
-                                                             bool withRID,
-                                                             Connection *connection)
+        bool withRID,
+        Connection *connection)
 {
     Protocol::FetchTagsResponse response(tag.id());
     response.setType(tag.tagType().name().toUtf8());
@@ -245,12 +245,11 @@ Protocol::FetchRelationsResponse HandlerHelper::fetchRelationsResponse(const Rel
                                             relation.relationType().name().toUtf8());
 }
 
-
 Flag::List HandlerHelper::resolveFlags(const QSet<QByteArray> &flagNames)
 {
     Flag::List flagList;
     flagList.reserve(flagNames.size());
-    Q_FOREACH (const QByteArray &flagName, flagNames) {
+    for (const QByteArray &flagName : flagNames) {
         const Flag flag = Flag::retrieveByNameOrCreate(QString::fromUtf8(flagName));
         if (!flag.isValid()) {
             throw HandlerException("Unable to create flag");
@@ -376,7 +375,7 @@ Collection HandlerHelper::collectionFromScope(const Scope &scope, Connection *co
     }
 
     const Collection::List c = qb.result();
-    if (c.count() == 0) {
+    if (c.isEmpty()) {
         return Collection();
     } else if (c.count() == 1) {
         return c.at(0);
@@ -385,7 +384,7 @@ Collection HandlerHelper::collectionFromScope(const Scope &scope, Connection *co
     }
 }
 
-Tag::List HandlerHelper::tagsFromScope(const Scope &scope, Connection* connection)
+Tag::List HandlerHelper::tagsFromScope(const Scope &scope, Connection *connection)
 {
     if (scope.scope() == Scope::Invalid || scope.scope() == Scope::HierarchicalRid) {
         throw HandlerException("Invalid tag scope");
