@@ -23,13 +23,12 @@
 #include "storage/notificationcollector.h"
 #include "tracer.h"
 #include "akonadiserver_debug.h"
+#include "utils.h"
 
 #include <private/standarddirs_p.h>
 #include <private/xdgbasedirs_p.h>
 
-#include <QLocalSocket>
 #include <QSettings>
-#include <QCoreApplication>
 #include <QThreadPool>
 #include <QPointer>
 #include <QDateTime>
@@ -38,12 +37,11 @@ using namespace Akonadi;
 using namespace Akonadi::Server;
 
 NotificationManager::NotificationManager()
-    : AkThread()
-    , mTimer(Q_NULLPTR)
-    , mNotifyThreadPool(Q_NULLPTR)
+    : AkThread(QStringLiteral("NotificationManager"))
+    , mTimer(nullptr)
+    , mNotifyThreadPool(nullptr)
     , mDebugNotifications(0)
 {
-    setObjectName(QStringLiteral("NotificationManager"));
 }
 
 NotificationManager::~NotificationManager()
@@ -89,15 +87,15 @@ void NotificationManager::registerConnection(quintptr socketDescriptor)
     NotificationSubscriber *subscriber = new NotificationSubscriber(this, socketDescriptor);
     qCDebug(AKONADISERVER_LOG) << "New notification connection (registered as" << subscriber << ")";
     connect(subscriber, &NotificationSubscriber::notificationDebuggingChanged,
-            this, [this](bool enabled) {
-                if (enabled) {
-                    ++mDebugNotifications;
-                } else {
-                    --mDebugNotifications;
-                }
-                Q_ASSERT(mDebugNotifications >= 0);
-                Q_ASSERT(mDebugNotifications <= mSubscribers.count());
-            });
+    this, [this](bool enabled) {
+        if (enabled) {
+            ++mDebugNotifications;
+        } else {
+            --mDebugNotifications;
+        }
+        Q_ASSERT(mDebugNotifications >= 0);
+        Q_ASSERT(mDebugNotifications <= mSubscribers.count());
+    });
 
     mSubscribers.push_back(subscriber);
 }
@@ -118,7 +116,7 @@ void NotificationManager::slotNotify(const Protocol::ChangeNotification::List &m
 {
     Q_ASSERT(QThread::currentThread() == thread());
 
-    Q_FOREACH (const Protocol::ChangeNotification &msg, msgs) {
+    for (const Protocol::ChangeNotification &msg : msgs) {
         if (msg.type() == Protocol::Command::CollectionChangeNotification) {
             Protocol::CollectionChangeNotification::appendAndCompress(mNotifications, msg);
         } else {
@@ -145,9 +143,9 @@ public:
     {
     }
 
-    void run() Q_DECL_OVERRIDE
-    {
-        Q_FOREACH (const auto &ntf, mNotifications) {
+    void run() Q_DECL_OVERRIDE {
+        for (const auto &ntf : qAsConst(mNotifications))
+        {
             if (mSubscriber) {
                 mSubscriber->notify(ntf);
             } else {
@@ -170,13 +168,13 @@ void NotificationManager::emitPendingNotifications()
     }
 
     if (mDebugNotifications == 0) {
-        Q_FOREACH (NotificationSubscriber *subscriber, mSubscribers) {
+        for (NotificationSubscriber *subscriber : qAsConst(mSubscribers)) {
             mNotifyThreadPool->start(new NotifyRunnable(subscriber, mNotifications));
         }
     } else {
         // When debugging notification we have to use a non-threaded approach
         // so that we can work with return value of notify()
-        Q_FOREACH (const auto &notification, mNotifications) {
+        for (const auto &notification : qAsConst(mNotifications)) {
             QVector<QByteArray> listeners;
             Q_FOREACH (NotificationSubscriber *subscriber, mSubscribers) {
                 if (subscriber->notify(notification)) {
@@ -192,13 +190,13 @@ void NotificationManager::emitPendingNotifications()
 }
 
 void NotificationManager::emitDebugNotification(const Protocol::ChangeNotification &ntf,
-                                                const QVector<QByteArray> &listeners)
+        const QVector<QByteArray> &listeners)
 {
     Protocol::DebugChangeNotification debugNtf;
     debugNtf.setNotification(ntf);
     debugNtf.setListeners(listeners);
     debugNtf.setTimestamp(QDateTime::currentMSecsSinceEpoch());
-    Q_FOREACH (NotificationSubscriber *subscriber, mSubscribers) {
+    for (NotificationSubscriber *subscriber : qAsConst(mSubscribers)) {
         mNotifyThreadPool->start(new NotifyRunnable(subscriber, { debugNtf }));
     }
 }
