@@ -29,12 +29,15 @@
 #include "entities.h" // Akonadi::Server::PimItem
 #include "storage/datastore.h"
 #include "tracer.h"
+#include "utils.h"
 #include "collectionreferencemanager.h"
 
 #include "preprocessormanageradaptor.h"
 
-namespace Akonadi {
-namespace Server {
+namespace Akonadi
+{
+namespace Server
+{
 
 const int gHeartbeatTimeoutInMSecs = 30000; // 30 sec heartbeat
 
@@ -55,7 +58,7 @@ const int gDeadlineItemProcessingTimeInSecs = 240;
 using namespace Akonadi::Server;
 
 // The one and only PreprocessorManager object
-PreprocessorManager *PreprocessorManager::mSelf = NULL;
+PreprocessorManager *PreprocessorManager::mSelf = nullptr;
 
 PreprocessorManager::PreprocessorManager()
     : QObject()
@@ -103,11 +106,8 @@ bool PreprocessorManager::init()
 
 void PreprocessorManager::done()
 {
-    if (!mSelf) {
-        return;
-    }
     delete mSelf;
-    mSelf = NULL;
+    mSelf = nullptr;
 }
 
 bool PreprocessorManager::isActive()
@@ -117,18 +117,18 @@ bool PreprocessorManager::isActive()
     if (!mEnabled) {
         return false;
     }
-    return mPreprocessorChain.count() > 0;
+    return !mPreprocessorChain.isEmpty();
 }
 
 PreprocessorInstance *PreprocessorManager::lockedFindInstance(const QString &id)
 {
-    Q_FOREACH (PreprocessorInstance *instance, mPreprocessorChain) {
+    for (PreprocessorInstance *instance : qAsConst(mPreprocessorChain)) {
         if (instance->id() == id) {
             return instance;
         }
     }
 
-    return NULL;
+    return nullptr;
 }
 
 void PreprocessorManager::registerInstance(const QString &id)
@@ -241,7 +241,7 @@ void PreprocessorManager::beginHandleItem(const PimItem &item, const DataStore *
         qCDebug(AKONADISERVER_LOG) << "PreprocessorManager::beginHandleItem(" << item.id() << "): the DataStore is in transaction, pushing item to a wait queue";
 
         // The calling thread data store is in a transaction: push the item into a wait queue
-        std::deque< qint64 > *waitQueue = mTransactionWaitQueueHash.value(dataStore, 0);
+        std::deque< qint64 > *waitQueue = mTransactionWaitQueueHash.value(dataStore, nullptr);
 
         if (!waitQueue) {
             // No wait queue for this transaction yet...
@@ -282,7 +282,7 @@ void PreprocessorManager::lockedActivateFirstPreprocessor(qint64 itemId)
 
 void PreprocessorManager::lockedKillWaitQueue(const DataStore *dataStore, bool disconnectSlots)
 {
-    std::deque< qint64 > *waitQueue = mTransactionWaitQueueHash.value(dataStore, 0);
+    std::deque< qint64 > *waitQueue = mTransactionWaitQueueHash.value(dataStore, nullptr);
     if (!waitQueue) {
         qCWarning(AKONADISERVER_LOG) << "PreprocessorManager::lockedKillWaitQueue(): called for dataStore which has no wait queue";
         return;
@@ -329,7 +329,7 @@ void PreprocessorManager::dataStoreTransactionCommitted()
         return;
     }
 
-    std::deque< qint64 > *waitQueue = mTransactionWaitQueueHash.value(dataStore, 0);
+    std::deque< qint64 > *waitQueue = mTransactionWaitQueueHash.value(dataStore, nullptr);
     if (!waitQueue) {
         qCWarning(AKONADISERVER_LOG) << "PreprocessorManager::dataStoreTransactionCommitted(): called for dataStore which has no wait queue";
         return;
@@ -422,7 +422,7 @@ void PreprocessorManager::heartbeat()
 
     QList< PreprocessorInstance *> firedPreprocessors;
 
-    Q_FOREACH (PreprocessorInstance *instance, mPreprocessorChain) {
+    for (PreprocessorInstance *instance : qAsConst(mPreprocessorChain)) {
         // In this loop we check for "stuck" preprocessors.
 
         int elapsedTime = instance->currentProcessingTime();
@@ -480,7 +480,7 @@ void PreprocessorManager::heartbeat()
     }
 
     // Kill the fired preprocessors, if any.
-    Q_FOREACH (PreprocessorInstance *instance, firedPreprocessors) {
+    for (PreprocessorInstance *instance : qAsConst(firedPreprocessors)) {
         lockedUnregisterInstance(instance->id());
     }
 }
