@@ -38,14 +38,12 @@
 #include "querycache.h"
 #include "queryhelper.h"
 #include "akonadiserver_debug.h"
+#include "storagedebugger.h"
 #include <utils.h>
 
 #include <private/externalpartstorage_p.h>
 
 #include <QCoreApplication>
-#include <QDir>
-#include <QEventLoop>
-#include <QSettings>
 #include <QString>
 #include <QStringList>
 #include <QThread>
@@ -55,9 +53,9 @@
 #include <QVariant>
 #include <QSqlDatabase>
 #include <QSqlDriver>
-#include <QSqlError>
-#include <QSqlField>
 #include <QSqlQuery>
+#include <QFile>
+#include <QElapsedTimer>
 
 using namespace Akonadi;
 using namespace Akonadi::Server;
@@ -71,11 +69,11 @@ QThreadStorage<DataStore *> DataStore::sInstances;
 #define TRANSACTION_MUTEX_UNLOCK if ( DbType::isSystemSQLite( m_database ) ) sTransactionMutex.unlock()
 
 #define setBoolPtr(ptr, val) \
-{ \
-    if ((ptr)) { \
-        *(ptr) = (val); \
-    } \
-}
+    { \
+        if ((ptr)) { \
+            *(ptr) = (val); \
+        } \
+    }
 
 /***************************************************************************
  *   DataStore                                                           *
@@ -84,8 +82,8 @@ DataStore::DataStore()
     : QObject()
     , m_dbOpened(false)
     , m_transactionLevel(0)
-    , mNotificationCollector(0)
-    , m_keepAliveTimer(0)
+    , mNotificationCollector(nullptr)
+    , m_keepAliveTimer(nullptr)
 {
     notificationCollector();
 
@@ -128,6 +126,16 @@ void DataStore::open()
         qCDebug(AKONADISERVER_LOG) << "Database" << m_database.databaseName() << "opened using driver" << m_database.driverName();
     }
 
+    StorageDebugger::instance()->addConnection(reinterpret_cast<qint64>(this),
+                                               QThread::currentThread()->objectName());
+    connect(QThread::currentThread(), &QThread::objectNameChanged,
+            this, [this](const QString &name) {
+                if (!name.isEmpty()) {
+                    StorageDebugger::instance()->changeConnection(reinterpret_cast<qint64>(this),
+                                                                  name);
+                }
+            });
+
     DbConfig::configuredDatabase()->initSession(m_database);
 }
 
@@ -163,6 +171,8 @@ void DataStore::close()
     m_transactionQueries.clear();
     QSqlDatabase::removeDatabase(m_connectionName);
 
+    StorageDebugger::instance()->removeConnection(reinterpret_cast<qint64>(this));
+
     m_dbOpened = false;
 }
 
@@ -204,7 +214,7 @@ bool DataStore::init()
 
 NotificationCollector *DataStore::notificationCollector()
 {
-    if (mNotificationCollector == 0) {
+    if (mNotificationCollector == nullptr) {
         mNotificationCollector = new NotificationCollector(this);
         NotificationManager *notificationManager = AkonadiServer::instance()->notificationManager();
         if (notificationManager) {
@@ -242,9 +252,9 @@ bool DataStore::setItemsFlags(const PimItem::List &items, const QVector<Flag> &f
 
     setBoolPtr(flagsChanged, false);
 
-    Q_FOREACH (const PimItem &item, items) {
+    for (const PimItem &item : items) {
         const Flag::List itemFlags = item.flags();
-        Q_FOREACH (const Flag &flag, itemFlags) {
+        for (const Flag &flag : itemFlags) {
             if (!flags.contains(flag)) {
                 removedFlags << flag.name().toLatin1();
                 Query::Condition cond;
@@ -335,7 +345,7 @@ bool DataStore::doAppendItemsFlag(const PimItem::List &items, const Flag &flag,
 
     if (!silent) {
         mNotificationCollector->itemsFlagsChanged(appendItems, QSet<QByteArray>() << flag.name().toLatin1(),
-                                                  QSet<QByteArray>(), col);
+                QSet<QByteArray>(), col);
     }
 
     return true;
@@ -345,17 +355,15 @@ bool DataStore::appendItemsFlags(const PimItem::List &items, const QVector<Flag>
                                  bool *flagsChanged, bool checkIfExists,
                                  const Collection &col, bool silent)
 {
-    QSet<QByteArray> added;
-
     QVariantList itemsIds;
     itemsIds.reserve(items.count());
-    Q_FOREACH (const PimItem &item, items) {
+    for (const PimItem &item : items) {
         itemsIds.append(item.id());
     }
 
     setBoolPtr(flagsChanged, false);
 
-    Q_FOREACH (const Flag &flag, flags) {
+    for (const Flag &flag : flags) {
         QSet<PimItem::Id> existing;
         if (checkIfExists) {
             QueryBuilder qb(PimItemFlagRelation::tableName(), QueryBuilder::Select);
@@ -408,7 +416,7 @@ bool DataStore::removeItemsFlags(const PimItem::List &items, const QVector<Flag>
     setBoolPtr(flagsChanged, false);
     itemsIds.reserve(items.count());
 
-    Q_FOREACH (const PimItem &item, items) {
+    for (const PimItem &item : items) {
         itemsIds << item.id();
         if (col.id() == -1) {
             col.setId(item.collectionId());
@@ -514,7 +522,7 @@ bool DataStore::doAppendItemsTag(const PimItem::List &items, const Tag &tag,
     QVariantList tagIds;
     QVariantList appendIds;
     PimItem::List appendItems;
-    Q_FOREACH (const PimItem &item, items) {
+    for (const PimItem &item : items) {
         if (existing.contains(item.id())) {
             continue;
         }
@@ -539,7 +547,7 @@ bool DataStore::doAppendItemsTag(const PimItem::List &items, const Tag &tag,
 
     if (!silent) {
         mNotificationCollector->itemsTagsChanged(appendItems, QSet<qint64>() << tag.id(),
-                                                 QSet<qint64>(), col);
+                QSet<qint64>(), col);
     }
 
     return true;
@@ -549,17 +557,15 @@ bool DataStore::appendItemsTags(const PimItem::List &items, const Tag::List &tag
                                 bool *tagsChanged, bool checkIfExists,
                                 const Collection &col, bool silent)
 {
-    QSet<QByteArray> added;
-
     QVariantList itemsIds;
     itemsIds.reserve(items.count());
-    Q_FOREACH (const PimItem &item, items) {
+    for (const PimItem &item : items) {
         itemsIds.append(item.id());
     }
 
     setBoolPtr(tagsChanged, false);
 
-    Q_FOREACH (const Tag &tag, tags) {
+    for (const Tag &tag : tags) {
         QSet<PimItem::Id> existing;
         if (checkIfExists) {
             QueryBuilder qb(PimItemTagRelation::tableName(), QueryBuilder::Select);
@@ -632,7 +638,7 @@ bool DataStore::removeItemsTags(const PimItem::List &items, const Tag::List &tag
         }
     }
 
-  return true;
+    return true;
 }
 
 bool DataStore::removeTags(const Tag::List &tags, bool silent)
@@ -669,7 +675,7 @@ bool DataStore::removeTags(const Tag::List &tags, bool silent)
         QueryBuilder qb(TagRemoteIdResourceRelation::tableName(), QueryBuilder::Select);
         qb.addColumn(TagRemoteIdResourceRelation::remoteIdFullColumnName());
         qb.addJoin(QueryBuilder::InnerJoin, Resource::tableName(),
-                    TagRemoteIdResourceRelation::resourceIdFullColumnName(), Resource::idFullColumnName());
+                   TagRemoteIdResourceRelation::resourceIdFullColumnName(), Resource::idFullColumnName());
         qb.addColumn(Resource::nameFullColumnName());
         qb.addValueCondition(TagRemoteIdResourceRelation::tagIdFullColumnName(), Query::Equals, tag.id());
         if (!qb.exec()) {
@@ -701,7 +707,6 @@ bool DataStore::removeTags(const Tag::List &tags, bool silent)
     return true;
 }
 
-
 /* --- ItemParts ----------------------------------------------------- */
 
 bool DataStore::removeItemParts(const PimItem &item, const QSet<QByteArray> &parts)
@@ -740,7 +745,7 @@ bool DataStore::invalidateItemCache(const PimItem &item)
 
     const Part::List parts = qb.result();
     // clear data field
-    Q_FOREACH (Part part, parts) { //krazy:exclude=foreach
+    for (Part part : parts) {
         if (!PartHelper::truncate(part)) {
             return false;
         }
@@ -815,7 +820,7 @@ bool DataStore::cleanupCollection_slow(Collection &collection)
     const QByteArray resource = collection.resource().name().toLatin1();
     mNotificationCollector->itemsRemoved(items, collection, resource);
 
-    Q_FOREACH (const PimItem &item, items) {
+    for (const PimItem &item : items) {
         if (!item.clearFlags()) {   // TODO: move out of loop and use only a single query
             return false;
         }
@@ -850,7 +855,7 @@ bool DataStore::cleanupCollection_slow(Collection &collection)
 
 static bool recursiveSetResourceId(const Collection &collection, qint64 resourceId)
 {
-    Transaction transaction(DataStore::self());
+    Transaction transaction(DataStore::self(), QStringLiteral("RECURSIVE SET RESOURCEID"));
 
     QueryBuilder qb(Collection::tableName(), QueryBuilder::Update);
     qb.addValueCondition(Collection::parentIdColumn(), Query::Equals, collection.id());
@@ -930,7 +935,7 @@ bool DataStore::appendMimeTypeForCollection(qint64 collectionId, const QStringLi
         return true;
     }
 
-    Q_FOREACH (const QString &mimeType, mimeTypes) {
+    for (const QString &mimeType : mimeTypes) {
         const auto &mt = MimeType::retrieveByNameOrCreate(mimeType);
         if (!mt.isValid()) {
             return false;
@@ -977,7 +982,7 @@ QVector<Collection> DataStore::virtualCollections(const PimItem &item)
 
     if (!qb.exec()) {
         qCDebug(AKONADISERVER_LOG) << "Error during selection of records from table CollectionPimItemRelation"
-                  << qb.query().lastError().text();
+                                   << qb.query().lastError().text();
         return QVector<Collection>();
     }
 
@@ -1011,7 +1016,7 @@ QMap<Entity::Id, QList<PimItem> > DataStore::virtualCollections(const PimItem::L
 
     if (!qb.exec()) {
         qCDebug(AKONADISERVER_LOG) << "Error during selection of records from table CollectionPimItemRelation"
-                  << qb.query().lastError().text();
+                                   << qb.query().lastError().text();
         return QMap<Entity::Id, QList<PimItem> >();
     }
 
@@ -1086,7 +1091,7 @@ bool DataStore::appendPimItem(QVector<Part> &parts,
     bool seen = false;
     Q_FOREACH (const Flag &flag, flags) {
         seen |= (flag.name() == QLatin1String(AKONADI_FLAG_SEEN)
-                || flag.name() == QLatin1String(AKONADI_FLAG_IGNORED));
+                 || flag.name() == QLatin1String(AKONADI_FLAG_IGNORED));
         if (!pimItem.addFlag(flag)) {
             return false;
         }
@@ -1130,7 +1135,7 @@ bool DataStore::unhideAllPimItems()
 bool DataStore::cleanupPimItems(const PimItem::List &items)
 {
     // generate relation removed notifications
-    Q_FOREACH (const PimItem &item, items) {
+    for (const PimItem &item : items) {
         SelectQueryBuilder<Relation> relationQuery;
         relationQuery.addValueCondition(Relation::leftIdFullColumnName(), Query::Equals, item.id());
         relationQuery.addValueCondition(Relation::rightIdFullColumnName(), Query::Equals, item.id());
@@ -1140,7 +1145,7 @@ bool DataStore::cleanupPimItems(const PimItem::List &items)
             throw HandlerException("Failed to obtain relations");
         }
         const Relation::List relations = relationQuery.result();
-        Q_FOREACH (const Relation &relation, relations) {
+        for (const Relation &relation : relations) {
             DataStore::self()->notificationCollector()->relationRemoved(relation);
         }
     }
@@ -1177,7 +1182,7 @@ bool DataStore::addCollectionAttribute(const Collection &col, const QByteArray &
         return false;
     }
 
-    if (qb.result().count() > 0) {
+    if (!qb.result().isEmpty()) {
         qCDebug(AKONADISERVER_LOG) << "Attribute" << key << "already exists for collection" << col.id();
         return false;
     }
@@ -1205,7 +1210,7 @@ bool DataStore::removeCollectionAttribute(const Collection &col, const QByteArra
     }
 
     const QVector<CollectionAttribute> result = qb.result();
-    Q_FOREACH (CollectionAttribute attr, result) {  //krazy:exclude=foreach
+    for (CollectionAttribute attr : result) {
         if (!attr.remove()) {
             throw HandlerException("Unable to remove collection attribute");
         }
@@ -1288,13 +1293,12 @@ QSqlQuery DataStore::retryLastTransaction(bool rollbackFirst)
     // because this has to be completely transparent to the original caller
     const int oldTransactionLevel = m_transactionLevel;
     m_transactionLevel = 0;
-    if (!beginTransaction()) {
+    if (!beginTransaction(QStringLiteral("RETRY LAST TRX"))) {
         m_transactionLevel = oldTransactionLevel;
         return QSqlQuery();
     }
     m_transactionLevel = oldTransactionLevel;
 
-    QSqlQuery ret;
     typedef QPair<QSqlQuery, bool> QueryBoolPair;
     QMutableVectorIterator<QueryBoolPair> iter(m_transactionQueries);
     while (iter.hasNext()) {
@@ -1317,7 +1321,7 @@ QSqlQuery DataStore::retryLastTransaction(bool rollbackFirst)
             copiedQuery.prepare(query.executedQuery());
             const QMap<QString, QVariant> boundValues = query.boundValues();
             int i = 0;
-            Q_FOREACH (const QVariant &value, boundValues) {
+            for (const QVariant &value : boundValues) {
                 copiedQuery.bindValue(i, value);
                 ++i;
             }
@@ -1347,25 +1351,36 @@ QSqlQuery DataStore::retryLastTransaction(bool rollbackFirst)
     return m_transactionQueries.last().first;
 }
 
-bool DataStore::beginTransaction()
+bool DataStore::beginTransaction(const QString &name)
 {
     if (!m_dbOpened) {
         return false;
     }
 
     if (m_transactionLevel == 0) {
+        QElapsedTimer timer;
+        timer.start();
         TRANSACTION_MUTEX_LOCK;
         if (DbType::type(m_database) == DbType::Sqlite) {
             m_database.exec(QStringLiteral("BEGIN IMMEDIATE TRANSACTION"));
+            StorageDebugger::instance()->addTransaction(reinterpret_cast<qint64>(this),
+                                                        name, timer.elapsed(),
+                                                        m_database.lastError().text());
             if (m_database.lastError().isValid()) {
                 debugLastDbError("DataStore::beginTransaction (SQLITE)");
                 TRANSACTION_MUTEX_UNLOCK;
                 return false;
             }
-        } else if (!m_database.driver()->beginTransaction()) {
-            debugLastDbError("DataStore::beginTransaction");
-            TRANSACTION_MUTEX_UNLOCK;
-            return false;
+        } else {
+            m_database.driver()->beginTransaction();
+            StorageDebugger::instance()->addTransaction(reinterpret_cast<qint64>(this),
+                                                        name, timer.elapsed(),
+                                                        m_database.lastError().text());
+            if (m_database.lastError().isValid()) {
+                debugLastDbError("DataStore::beginTransaction");
+                TRANSACTION_MUTEX_UNLOCK;
+                return false;
+            }
         }
 
         if (DbType::type(m_database) == DbType::PostgreSQL) {
@@ -1398,7 +1413,12 @@ bool DataStore::rollbackTransaction()
     if (m_transactionLevel == 0) {
         QSqlDriver *driver = m_database.driver();
         Q_EMIT transactionRolledBack();
-        if (!driver->rollbackTransaction()) {
+        QElapsedTimer timer; timer.start();
+        driver->rollbackTransaction();
+        StorageDebugger::instance()->removeTransaction(reinterpret_cast<qint64>(this),
+                                                       false, timer.elapsed(),
+                                                       m_database.lastError().text());
+        if (m_database.lastError().isValid()) {
             TRANSACTION_MUTEX_UNLOCK;
             debugLastDbError("DataStore::rollbackTransaction");
             return false;
@@ -1424,7 +1444,12 @@ bool DataStore::commitTransaction()
 
     if (m_transactionLevel == 1) {
         QSqlDriver *driver = m_database.driver();
-        if (!driver->commitTransaction()) {
+        QElapsedTimer timer; timer.start();
+        driver->commitTransaction();
+        StorageDebugger::instance()->removeTransaction(reinterpret_cast<qint64>(this),
+                                                       true, timer.elapsed(),
+                                                       m_database.lastError().text());
+        if (m_database.lastError().isValid()) {
             debugLastDbError("DataStore::commitTransaction");
             rollbackTransaction();
             return false;
