@@ -21,14 +21,18 @@
 #define DBCONFIGMYSQL_H
 
 #include "dbconfig.h"
+#include <QObject>
+#include <QProcess>
 
-class QProcess;
-
-namespace Akonadi {
-namespace Server {
-
-class DbConfigMysql : public DbConfig
+namespace Akonadi
 {
+namespace Server
+{
+
+class DbConfigMysql : public QObject, public DbConfig
+{
+    Q_OBJECT
+
 public:
     DbConfigMysql();
 
@@ -75,6 +79,9 @@ public:
     /// reimpl
     void initSession(const QSqlDatabase &database) Q_DECL_OVERRIDE;
 
+private Q_SLOTS:
+    void processFinished(int exitCode, QProcess::ExitStatus exitStatus);
+
 private:
     int parseCommandLineToolsVersion() const;
 
