@@ -26,14 +26,9 @@
 #include "entities.h"
 #include "akonadiserver_debug.h"
 
-#include <QFile>
-#include <QPair>
 #include <QStringList>
-#include <QVariant>
-#include <QSqlField>
-#include <QSqlRecord>
 #include <QSqlQuery>
-#include <QSqlError>
+#include <QDateTime>
 
 #include <algorithm>
 
@@ -64,8 +59,8 @@ DbInitializer::Ptr DbInitializer::createInstance(const QSqlDatabase &database, S
 
 DbInitializer::DbInitializer(const QSqlDatabase &database)
     : mDatabase(database)
-    , mSchema(0)
-    , mTestInterface(0)
+    , mSchema(nullptr)
+    , mTestInterface(nullptr)
     , m_noForeignKeyContraints(false)
 {
     m_introspector = DbIntrospector::createInstance(mDatabase);
@@ -172,16 +167,16 @@ void DbInitializer::checkForeignKeys(const TableDescription &tableDescription)
                 if (!existingForeignKey.column.isEmpty()) {
                     // there's a constraint on this column, check if it's the correct one
                     if (QString::compare(existingForeignKey.refTable, column.refTable + QLatin1Literal("table"), Qt::CaseInsensitive) == 0
-                        && QString::compare(existingForeignKey.refColumn, column.refColumn, Qt::CaseInsensitive) == 0
-                        && QString::compare(existingForeignKey.onUpdate, referentialActionToString(column.onUpdate), Qt::CaseInsensitive) == 0
-                        && QString::compare(existingForeignKey.onDelete, referentialActionToString(column.onDelete), Qt::CaseInsensitive) == 0) {
+                            && QString::compare(existingForeignKey.refColumn, column.refColumn, Qt::CaseInsensitive) == 0
+                            && QString::compare(existingForeignKey.onUpdate, referentialActionToString(column.onUpdate), Qt::CaseInsensitive) == 0
+                            && QString::compare(existingForeignKey.onDelete, referentialActionToString(column.onDelete), Qt::CaseInsensitive) == 0) {
                         continue; // all good
                     }
 
                     const QString statement = buildRemoveForeignKeyConstraintStatement(existingForeignKey, tableDescription);
                     if (!statement.isEmpty()) {
                         qCDebug(AKONADISERVER_LOG) << "Found existing foreign constraint that doesn't match the schema:" << existingForeignKey.name
-                                  << existingForeignKey.column << existingForeignKey.refTable << existingForeignKey.refColumn;
+                                                   << existingForeignKey.column << existingForeignKey.refTable << existingForeignKey.refColumn;
                         m_removedForeignKeys << statement;
                     }
                 }
@@ -199,7 +194,7 @@ void DbInitializer::checkForeignKeys(const TableDescription &tableDescription)
                 const QString statement = buildRemoveForeignKeyConstraintStatement(existingForeignKey, tableDescription);
                 if (!statement.isEmpty()) {
                     qCDebug(AKONADISERVER_LOG) << "Found unexpected foreign key constraint:" << existingForeignKey.name << existingForeignKey.column
-                              << existingForeignKey.refTable << existingForeignKey.refColumn;
+                                               << existingForeignKey.refTable << existingForeignKey.refColumn;
                     m_removedForeignKeys << statement;
                 }
             }
@@ -281,7 +276,7 @@ bool DbInitializer::updateIndexesAndConstraints()
 
 void DbInitializer::execPendingQueries(const QStringList &queries)
 {
-    Q_FOREACH (const QString &statement, queries) {
+    for (const QString &statement : queries) {
         qCDebug(AKONADISERVER_LOG) << statement;
         execQuery(statement);
     }
@@ -350,9 +345,9 @@ QString DbInitializer::buildCreateIndexStatement(const TableDescription &tableDe
         columns.reserve(indexDescription.columns.count());
         std::transform(indexDescription.columns.cbegin(), indexDescription.columns.cend(),
                        std::back_insert_iterator<QStringList>(columns),
-                       [&indexDescription](const QString &column) {
-                            return QStringLiteral("%1 %2").arg(column, indexDescription.sort);
-                       });
+        [&indexDescription](const QString & column) {
+            return QStringLiteral("%1 %2").arg(column, indexDescription.sort);
+        });
     }
 
     return QStringLiteral("CREATE %1 INDEX %2 ON %3 (%4)")
