@@ -28,14 +28,13 @@
 #include "akonadi.h"
 #include "handler/search.h"
 
-#include <QDebug>
 
 using namespace Akonadi;
 using namespace Akonadi::Server;
 
 NotificationCollector::NotificationCollector(QObject *parent)
     : QObject(parent)
-    , mDb(0)
+    , mDb(nullptr)
 {
 }
 
@@ -71,10 +70,10 @@ void NotificationCollector::itemChanged(const PimItem &item,
 }
 
 void NotificationCollector::itemsFlagsChanged(const PimItem::List &items,
-                                              const QSet< QByteArray > &addedFlags,
-                                              const QSet< QByteArray > &removedFlags,
-                                              const Collection &collection,
-                                              const QByteArray &resource)
+        const QSet<QByteArray> &addedFlags,
+        const QSet<QByteArray> &removedFlags,
+        const Collection &collection,
+        const QByteArray &resource)
 {
     int seenCount = (addedFlags.contains(AKONADI_FLAG_SEEN) || addedFlags.contains(AKONADI_FLAG_IGNORED) ? items.count() : 0);
     seenCount -= (removedFlags.contains(AKONADI_FLAG_SEEN) || removedFlags.contains(AKONADI_FLAG_IGNORED) ? items.count() : 0);
@@ -84,19 +83,19 @@ void NotificationCollector::itemsFlagsChanged(const PimItem::List &items,
 }
 
 void NotificationCollector::itemsTagsChanged(const PimItem::List &items,
-                                             const QSet<qint64> &addedTags,
-                                             const QSet<qint64> &removedTags,
-                                             const Collection &collection,
-                                             const QByteArray &resource)
+        const QSet<qint64> &addedTags,
+        const QSet<qint64> &removedTags,
+        const Collection &collection,
+        const QByteArray &resource)
 {
     itemNotification(Protocol::ItemChangeNotification::ModifyTags, items, collection, Collection(), resource, QSet<QByteArray>(), QSet<QByteArray>(), QSet<QByteArray>(), addedTags, removedTags);
 }
 
 void NotificationCollector::itemsRelationsChanged(const PimItem::List &items,
-                                                  const Relation::List &addedRelations,
-                                                  const Relation::List &removedRelations,
-                                                  const Collection &collection,
-                                                  const QByteArray &resource)
+        const Relation::List &addedRelations,
+        const Relation::List &removedRelations,
+        const Collection &collection,
+        const QByteArray &resource)
 {
     itemNotification(Protocol::ItemChangeNotification::ModifyRelations, items, collection, Collection(), resource, QSet<QByteArray>(), QSet<QByteArray>(), QSet<QByteArray>(), QSet<qint64>(), QSet<qint64>(), addedRelations, removedRelations);
 }
@@ -111,8 +110,8 @@ void NotificationCollector::itemsMoved(const PimItem::List &items,
 }
 
 void NotificationCollector::itemsRemoved(const PimItem::List &items,
-                                         const Collection &collection,
-                                         const QByteArray &resource)
+        const Collection &collection,
+        const QByteArray &resource)
 {
     itemNotification(Protocol::ItemChangeNotification::Remove, items, collection, Collection(), resource);
 }
@@ -128,26 +127,26 @@ void NotificationCollector::itemsUnlinked(const PimItem::List &items, const Coll
 }
 
 void NotificationCollector::collectionAdded(const Collection &collection,
-                                            const QByteArray &resource)
+        const QByteArray &resource)
 {
-    if (AkonadiServer::instance()->cacheCleaner()) {
-        AkonadiServer::instance()->cacheCleaner()->collectionAdded(collection.id());
+    if (auto cleaner = AkonadiServer::instance()->cacheCleaner()) {
+        cleaner->collectionAdded(collection.id());
     }
-    if (AkonadiServer::instance()->intervalChecker()) {
-        AkonadiServer::instance()->intervalChecker()->collectionAdded(collection.id());
+    if (auto checker = AkonadiServer::instance()->intervalChecker()) {
+        checker->collectionAdded(collection.id());
     }
     collectionNotification(Protocol::CollectionChangeNotification::Add, collection, collection.parentId(), -1, resource);
 }
 
 void NotificationCollector::collectionChanged(const Collection &collection,
-                                              const QList<QByteArray> &changes,
-                                              const QByteArray &resource)
+        const QList<QByteArray> &changes,
+        const QByteArray &resource)
 {
-    if (AkonadiServer::instance()->cacheCleaner()) {
-        AkonadiServer::instance()->cacheCleaner()->collectionChanged(collection.id());
+    if (auto cleaner = AkonadiServer::instance()->cacheCleaner()) {
+        cleaner->collectionChanged(collection.id());
     }
-    if (AkonadiServer::instance()->intervalChecker()) {
-        AkonadiServer::instance()->intervalChecker()->collectionChanged(collection.id());
+    if (auto checker = AkonadiServer::instance()->intervalChecker()) {
+        checker->collectionChanged(collection.id());
     }
     if (changes.contains(AKONADI_PARAM_ENABLED) || changes.contains(AKONADI_PARAM_REFERENCED)) {
         CollectionStatistics::self()->invalidateCollection(collection);
@@ -156,52 +155,52 @@ void NotificationCollector::collectionChanged(const Collection &collection,
 }
 
 void NotificationCollector::collectionMoved(const Collection &collection,
-                                            const Collection &source,
-                                            const QByteArray &resource,
-                                            const QByteArray &destResource)
+        const Collection &source,
+        const QByteArray &resource,
+        const QByteArray &destResource)
 {
-    if (AkonadiServer::instance()->cacheCleaner()) {
-        AkonadiServer::instance()->cacheCleaner()->collectionChanged(collection.id());
+    if (auto cleaner = AkonadiServer::instance()->cacheCleaner()) {
+        cleaner->collectionChanged(collection.id());
     }
-    if (AkonadiServer::instance()->intervalChecker()) {
-        AkonadiServer::instance()->intervalChecker()->collectionChanged(collection.id());
+    if (auto checker = AkonadiServer::instance()->intervalChecker()) {
+        checker->collectionChanged(collection.id());
     }
     collectionNotification(Protocol::CollectionChangeNotification::Move, collection, source.id(), collection.parentId(), resource, QSet<QByteArray>(), destResource);
 }
 
 void NotificationCollector::collectionRemoved(const Collection &collection,
-                                              const QByteArray &resource)
+        const QByteArray &resource)
 {
-    if (AkonadiServer::instance()->cacheCleaner()) {
-        AkonadiServer::instance()->cacheCleaner()->collectionRemoved(collection.id());
+    if (auto cleaner = AkonadiServer::instance()->cacheCleaner()) {
+        cleaner->collectionRemoved(collection.id());
     }
-    if (AkonadiServer::instance()->intervalChecker()) {
-        AkonadiServer::instance()->intervalChecker()->collectionRemoved(collection.id());
+    if (auto checker = AkonadiServer::instance()->intervalChecker()) {
+        checker->collectionRemoved(collection.id());
     }
     CollectionStatistics::self()->invalidateCollection(collection);
     collectionNotification(Protocol::CollectionChangeNotification::Remove, collection, collection.parentId(), -1, resource);
 }
 
 void NotificationCollector::collectionSubscribed(const Collection &collection,
-                                                 const QByteArray &resource)
+        const QByteArray &resource)
 {
-    if (AkonadiServer::instance()->cacheCleaner()) {
-        AkonadiServer::instance()->cacheCleaner()->collectionAdded(collection.id());
+    if (auto cleaner = AkonadiServer::instance()->cacheCleaner()) {
+        cleaner->collectionAdded(collection.id());
     }
-    if (AkonadiServer::instance()->intervalChecker()) {
-        AkonadiServer::instance()->intervalChecker()->collectionAdded(collection.id());
+    if (auto checker = AkonadiServer::instance()->intervalChecker()) {
+        checker->collectionAdded(collection.id());
     }
     collectionNotification(Protocol::CollectionChangeNotification::Subscribe, collection, collection.parentId(), -1, resource, QSet<QByteArray>());
 }
 
 void NotificationCollector::collectionUnsubscribed(const Collection &collection,
-                                                   const QByteArray &resource)
+        const QByteArray &resource)
 {
-    if (AkonadiServer::instance()->cacheCleaner()) {
-        AkonadiServer::instance()->cacheCleaner()->collectionRemoved(collection.id());
+    if (auto cleaner = AkonadiServer::instance()->cacheCleaner()) {
+        cleaner->collectionRemoved(collection.id());
     }
-    if (AkonadiServer::instance()->intervalChecker()) {
-        AkonadiServer::instance()->intervalChecker()->collectionRemoved(collection.id());
+    if (auto checker = AkonadiServer::instance()->intervalChecker()) {
+        checker->collectionRemoved(collection.id());
     }
     CollectionStatistics::self()->invalidateCollection(collection);
     collectionNotification(Protocol::CollectionChangeNotification::Unsubscribe, collection, collection.parentId(), -1, resource, QSet<QByteArray>());
@@ -253,11 +252,11 @@ void NotificationCollector::setSessionId(const QByteArray &sessionId)
 }
 
 void NotificationCollector::itemNotification(Protocol::ItemChangeNotification::Operation op,
-                                             const PimItem &item,
-                                             const Collection &collection,
-                                             const Collection &collectionDest,
-                                             const QByteArray &resource,
-                                             const QSet<QByteArray> &parts)
+        const PimItem &item,
+        const Collection &collection,
+        const Collection &collectionDest,
+        const QByteArray &resource,
+        const QSet<QByteArray> &parts)
 {
     PimItem::List items;
     items << item;
@@ -265,25 +264,24 @@ void NotificationCollector::itemNotification(Protocol::ItemChangeNotification::O
 }
 
 void NotificationCollector::itemNotification(Protocol::ItemChangeNotification::Operation op,
-                                             const PimItem::List &items,
-                                             const Collection &collection,
-                                             const Collection &collectionDest,
-                                             const QByteArray &resource,
-                                             const QSet<QByteArray> &parts,
-                                             const QSet<QByteArray> &addedFlags,
-                                             const QSet<QByteArray> &removedFlags,
-                                             const QSet<qint64> &addedTags,
-                                             const QSet<qint64> &removedTags,
-                                             const Relation::List &addedRelations,
-                                             const Relation::List &removedRelations)
+        const PimItem::List &items,
+        const Collection &collection,
+        const Collection &collectionDest,
+        const QByteArray &resource,
+        const QSet<QByteArray> &parts,
+        const QSet<QByteArray> &addedFlags,
+        const QSet<QByteArray> &removedFlags,
+        const QSet<qint64> &addedTags,
+        const QSet<qint64> &removedTags,
+        const Relation::List &addedRelations,
+        const Relation::List &removedRelations)
 {
-    Collection notificationDestCollection;
     QMap<Entity::Id, QList<PimItem> > vCollections;
 
     if ((op == Protocol::ItemChangeNotification::Modify) ||
-        (op == Protocol::ItemChangeNotification::ModifyFlags) ||
-        (op == Protocol::ItemChangeNotification::ModifyTags) ||
-        (op == Protocol::ItemChangeNotification::ModifyRelations)) {
+            (op == Protocol::ItemChangeNotification::ModifyFlags) ||
+            (op == Protocol::ItemChangeNotification::ModifyTags) ||
+            (op == Protocol::ItemChangeNotification::ModifyRelations)) {
         vCollections = DataStore::self()->virtualCollections(items);
     }
 
@@ -359,19 +357,19 @@ void NotificationCollector::itemNotification(Protocol::ItemChangeNotification::O
     // Add and ModifyFlags are handled incrementally
     // (see itemAdded() and itemsFlagsChanged())
     if (msg.operation() != Protocol::ItemChangeNotification::Add
-        && msg.operation() != Protocol::ItemChangeNotification::ModifyFlags) {
+            && msg.operation() != Protocol::ItemChangeNotification::ModifyFlags) {
         CollectionStatistics::self()->invalidateCollection(col);
     }
     dispatchNotification(msg);
 }
 
 void NotificationCollector::collectionNotification(Protocol::CollectionChangeNotification::Operation op,
-                                                   const Collection &collection,
-                                                   Collection::Id source,
-                                                   Collection::Id destination,
-                                                   const QByteArray &resource,
-                                                   const QSet<QByteArray> &changes,
-                                                   const QByteArray &destResource)
+        const Collection &collection,
+        Collection::Id source,
+        Collection::Id destination,
+        const QByteArray &resource,
+        const QSet<QByteArray> &changes,
+        const QByteArray &destResource)
 {
     Protocol::CollectionChangeNotification msg;
     msg.setOperation(op);
@@ -398,9 +396,9 @@ void NotificationCollector::collectionNotification(Protocol::CollectionChangeNot
 }
 
 void NotificationCollector::tagNotification(Protocol::TagChangeNotification::Operation op,
-                                             const Tag &tag,
-                                             const QByteArray &resource,
-                                             const QString &remoteId
+        const Tag &tag,
+        const QByteArray &resource,
+        const QString &remoteId
                                            )
 {
     Protocol::TagChangeNotification msg;
@@ -414,7 +412,7 @@ void NotificationCollector::tagNotification(Protocol::TagChangeNotification::Ope
 }
 
 void NotificationCollector::relationNotification(Protocol::RelationChangeNotification::Operation op,
-                                                 const Relation &relation)
+        const Relation &relation)
 {
     Protocol::RelationChangeNotification msg;
     msg.setOperation(op);
