@@ -51,10 +51,9 @@ using namespace Akonadi;
 using namespace Akonadi::Server;
 
 StorageJanitor::StorageJanitor(QObject *parent)
-    : AkThread(QThread::IdlePriority, parent)
+    : AkThread(QStringLiteral("StorageJanitor"), QThread::IdlePriority, parent)
     , m_lostFoundCollectionId(-1)
 {
-    setObjectName(QStringLiteral("StorageJanitor"));
 }
 
 StorageJanitor::~StorageJanitor()
@@ -98,7 +97,9 @@ void StorageJanitor::check() // implementation of `akonadictl fsck`
 
     inform("Checking collection tree consistency...");
     const Collection::List cols = Collection::retrieveAll();
-    std::for_each(cols.begin(), cols.end(), [this](const Collection &col) { checkPathToRoot(col); });
+    std::for_each(cols.begin(), cols.end(), [this](const Collection & col) {
+        checkPathToRoot(col);
+    });
 
     inform("Looking for items not belonging to a valid collection...");
     findOrphanedItems();
@@ -147,7 +148,7 @@ qint64 StorageJanitor::lostAndFoundCollection()
         return m_lostFoundCollectionId;
     }
 
-    Transaction transaction(DataStore::self());
+    Transaction transaction(DataStore::self(), QStringLiteral("JANITOR LOST+FOUND"));
     Resource lfRes = Resource::retrieveByName(QStringLiteral("akonadi_lost+found_resource"));
     if (!lfRes.isValid()) {
         lfRes.setName(QStringLiteral("akonadi_lost+found_resource"));
@@ -230,7 +231,7 @@ void StorageJanitor::findOrphanedResources()
     if (orphanResourcesSize > 0) {
         QStringList resourceNames;
         resourceNames.reserve(orphanResourcesSize);
-        Q_FOREACH (const Resource &resource, orphanResources) {
+        for (const Resource &resource : orphanResources) {
             resourceNames.append(resource.name());
         }
         inform(QStringLiteral("Found %1 orphan resources: %2").arg(orphanResources.size()). arg(resourceNames.join(QLatin1Char(','))));
@@ -293,7 +294,7 @@ void StorageJanitor::findOrphanedItems()
     if (!orphans.isEmpty()) {
         inform(QLatin1Literal("Found ") + QString::number(orphans.size()) + QLatin1Literal(" orphan items."));
         // Attach to lost+found collection
-        Transaction transaction(DataStore::self());
+        Transaction transaction(DataStore::self(), QStringLiteral("JANITOR ORPHANS"));
         QueryBuilder qb(PimItem::tableName(), QueryBuilder::Update);
         qint64 col = lostAndFoundCollection();
         if (col == -1) {
@@ -439,7 +440,7 @@ void StorageJanitor::verifyExternalParts()
     const QSet<QString> unreferencedFiles = existingFiles - usedFiles;
     if (!unreferencedFiles.isEmpty()) {
         const QString lfDir = StandardDirs::saveDir("data", QStringLiteral("file_lost+found"));
-        Q_FOREACH (const QString &file, unreferencedFiles) {
+        for (const QString &file : unreferencedFiles) {
             inform(QLatin1Literal("Found unreferenced external file: ") + file);
             const QFileInfo f(file);
             QFile::rename(file, lfDir + QDir::separator() + f.fileName());
@@ -461,7 +462,7 @@ void StorageJanitor::findDirtyObjects()
         return;
     }
     const Collection::List ridLessCols = cqb.result();
-    Q_FOREACH (const Collection &col, ridLessCols) {
+    for (const Collection &col : ridLessCols) {
         inform(QLatin1Literal("Collection \"") + col.name() + QLatin1Literal("\" (id: ") + QString::number(col.id())
                + QLatin1Literal(") has no RID."));
     }
@@ -476,7 +477,7 @@ void StorageJanitor::findDirtyObjects()
         return;
     }
     const PimItem::List ridLessItems = iqb1.result();
-    Q_FOREACH (const PimItem &item, ridLessItems) {
+    for (const PimItem &item : ridLessItems) {
         inform(QLatin1Literal("Item \"") + QString::number(item.id()) + QLatin1Literal("\" has no RID."));
     }
     inform(QLatin1Literal("Found ") + QString::number(ridLessItems.size()) + QLatin1Literal(" items without RID."));
@@ -490,7 +491,7 @@ void StorageJanitor::findDirtyObjects()
         return;
     }
     const PimItem::List dirtyItems = iqb2.result();
-    Q_FOREACH (const PimItem &item, dirtyItems) {
+    for (const PimItem &item : dirtyItems) {
         inform(QLatin1Literal("Item \"") + QString::number(item.id()) + QLatin1Literal("\" has RID and is dirty."));
     }
     inform(QLatin1Literal("Found ") + QString::number(dirtyItems.size()) + QLatin1Literal(" dirty items."));
@@ -502,31 +503,31 @@ void StorageJanitor::findRIDDuplicates()
     qb.addColumn(Collection::idColumn());
     qb.addColumn(Collection::nameColumn());
     qb.exec();
-  
+
     while (qb.query().next()) {
         const Collection::Id id = qb.query().value(0).value<Collection::Id>();
         const QString name = qb.query().value(1).toString();
         inform(QStringLiteral("Checking ") + name);
-    
+
         QueryBuilder duplicates(PimItem::tableName(), QueryBuilder::Select);
         duplicates.addColumn(PimItem::remoteIdColumn());
         duplicates.addColumn(QStringLiteral("count(") + PimItem::idColumn() + QStringLiteral(") as cnt"));
         duplicates.addValueCondition(PimItem::remoteIdColumn(), Query::IsNot, QVariant());
         duplicates.addValueCondition(PimItem::collectionIdColumn(), Query::Equals, id);
         duplicates.addGroupColumn(PimItem::remoteIdColumn());
-        duplicates.addValueCondition(QStringLiteral("count(") + PimItem::idColumn() + QStringLiteral(")"), Query::Greater, 1, QueryBuilder::HavingCondition);
+        duplicates.addValueCondition(QStringLiteral("count(") + PimItem::idColumn() + QLatin1Char(')'), Query::Greater, 1, QueryBuilder::HavingCondition);
         duplicates.exec();
-    
+
         Akonadi::Server::Collection col = Akonadi::Server::Collection::retrieveById(id);
         const QVector<Akonadi::Server::MimeType> contentMimeTypes = col.mimeTypes();
         QVariantList contentMimeTypesVariantList;
-        Q_FOREACH (const Akonadi::Server::MimeType &mimeType, contentMimeTypes) {
+        for (const Akonadi::Server::MimeType &mimeType : contentMimeTypes) {
             contentMimeTypesVariantList << mimeType.id();
         }
         while (duplicates.query().next()) {
             const QString rid = duplicates.query().value(0).toString();
             inform(QStringLiteral("Found duplicates ") + rid);
-    
+
             QueryBuilder items(PimItem::tableName(), QueryBuilder::Delete);
             items.addValueCondition(PimItem::remoteIdColumn(), Query::Equals, rid);
             items.addValueCondition(PimItem::mimeTypeIdColumn(), Query::NotIn, contentMimeTypesVariantList);
@@ -582,7 +583,7 @@ void StorageJanitor::checkSizeTreshold()
         inform(QStringLiteral("Found %1 parts to be moved to external files").arg(query.size()));
 
         while (query.next()) {
-            Transaction transaction(DataStore::self());
+            Transaction transaction(DataStore::self(), QStringLiteral("JANITOR CHECK SIZE THRESHOLD"));
             Part part = Part::retrieveById(query.value(0).toLongLong());
             const QByteArray name = ExternalPartStorage::nameForPartId(part.id());
             const QString partPath = ExternalPartStorage::resolveAbsolutePath(name);
@@ -628,7 +629,7 @@ void StorageJanitor::checkSizeTreshold()
         inform(QStringLiteral("Found %1 parts to be moved to database").arg(query.size()));
 
         while (query.next()) {
-            Transaction transaction(DataStore::self());
+            Transaction transaction(DataStore::self(), QStringLiteral("JANITOR CHECK SIZE THRESHOLD 2"));
             Part part = Part::retrieveById(query.value(0).toLongLong());
             const QString partPath = ExternalPartStorage::resolveAbsolutePath(part.data());
             QFile f(partPath);
@@ -701,7 +702,6 @@ void StorageJanitor::migrateToLevelledCacheHierarchy()
     }
 }
 
-
 void StorageJanitor::inform(const char *msg)
 {
     inform(QLatin1String(msg));
