@@ -1,7 +1,7 @@
 /*
     Copyright (c) 2006 - 2007 Volker Krause <vkrause@kde.org>
     Copyright (c) 2008 Stephen Kelly <steveire@gmail.com>
-    Copyright (c) 2012 Laurent Montel <montel@kde.org>
+    Copyright (C) 2012-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -23,7 +23,6 @@
 
 #include "dragdropmanager_p.h"
 
-#include <QDebug>
 #include <QTimer>
 #include <QApplication>
 #include <QDragMoveEvent>
@@ -53,7 +52,7 @@ public:
 #ifndef QT_NO_DRAGANDDROP
         , mDragDropManager(new DragDropManager(mParent))
 #endif
-        , mXmlGuiClient(0)
+        , mXmlGuiClient(nullptr)
         , mDefaultPopupMenu(QStringLiteral("akonadi_collectionview_contextmenu"))
     {
     }
@@ -108,7 +107,7 @@ void EntityTreeView::Private::slotSelectionChanged(const QItemSelection &selecte
 {
     Q_UNUSED(deselected)
     const int column = 0;
-    foreach (const QItemSelectionRange &range, selected) {
+    for (const QItemSelectionRange &range : selected) {
         const QModelIndex index = range.topLeft();
 
         if (index.column() > 0) {
