@@ -71,14 +71,14 @@ ErrorOverlay::ErrorOverlay(QWidget *baseWidget, QWidget *parent)
     // check existing overlays to detect cascading
     for (QVector<QPair< QPointer<QWidget>, QPointer<QWidget> > >::Iterator it = sInstanceOverlay->baseWidgets.begin();
             it != sInstanceOverlay->baseWidgets.end();) {
-        if ((*it).first == 0 || (*it).second == 0) {
+        if ((*it).first == nullptr || (*it).second == nullptr) {
             // garbage collection
             it = sInstanceOverlay->baseWidgets.erase(it);
             continue;
         }
         if (isParentOf((*it).first, baseWidget)) {
             // parent already has an overlay, kill ourselves
-            mBaseWidget = 0;
+            mBaseWidget = nullptr;
             hide();
             deleteLater();
             return;
@@ -128,7 +128,7 @@ ErrorOverlay::ErrorOverlay(QWidget *baseWidget, QWidget *parent)
     reposition();
 }
 
-ErrorOverlay::~ ErrorOverlay()
+ErrorOverlay::~ErrorOverlay()
 {
     if (mBaseWidget && !mBaseWidgetIsParent) {
         mBaseWidget->setEnabled(mPreviousState);
